package Bio::Emboss::Methods;

# automatically generated by scripts/get_methods.pl on Mon Jul 19 16:15:21 2004

# This file defines the methods that are available for certain classes
# (i.e. certain EMBOSS types "AjP...")
#
# If an EMBOSS library function has an AjP... type as a first parameter,
# this function can be used as a method on that data type.
#
# This information is extracted from .xs files by "scripts/get_methods.pl"
#
# Bio::Emboss.pm can EXPORT several functions on request into the callers
# namespace. Lists of functions are created for some EXPORT tags.


*Bio::Emboss::Atom::ajXyzAtomDel = *Bio::Emboss::ajXyzAtomDel;
*Bio::Emboss::Atom::ajXyzInContact = *Bio::Emboss::ajXyzInContact;
*Bio::Emboss::Atom::ajXyzAtomDistance = *Bio::Emboss::ajXyzAtomDistance;
*Bio::Emboss::Atom::ajXyzVdwRad = *Bio::Emboss::ajXyzVdwRad;

*Bio::Emboss::Chain::ajXyzChainDel = *Bio::Emboss::ajXyzChainDel;

*Bio::Emboss::Cmap::ajXyzCmapDel = *Bio::Emboss::ajXyzCmapDel;

*Bio::Emboss::FeattabIn::ajFeatUfoRead = *Bio::Emboss::ajFeatUfoRead;
*Bio::Emboss::FeattabIn::ajFeatRead = *Bio::Emboss::ajFeatRead;
*Bio::Emboss::FeattabIn::ajFeattabInClear = *Bio::Emboss::ajFeattabInClear;
*Bio::Emboss::FeattabIn::ajFeattabInDel = *Bio::Emboss::ajFeattabInDel;

*Bio::Emboss::FeattabOut::ajFeattabOutDel = *Bio::Emboss::ajFeattabOutDel;
*Bio::Emboss::FeattabOut::ajFeattabOutFile = *Bio::Emboss::ajFeattabOutFile;
*Bio::Emboss::FeattabOut::ajFeattabOutFilename = *Bio::Emboss::ajFeattabOutFilename;
*Bio::Emboss::FeattabOut::ajFeattabOutIsOpen = *Bio::Emboss::ajFeattabOutIsOpen;
*Bio::Emboss::FeattabOut::ajFeattabOutOpen = *Bio::Emboss::ajFeattabOutOpen;
*Bio::Emboss::FeattabOut::ajFeattabOutSet = *Bio::Emboss::ajFeattabOutSet;
*Bio::Emboss::FeattabOut::ajFeatWrite = *Bio::Emboss::ajFeatWrite;

*Bio::Emboss::Feattable::ajFeattableCopy = *Bio::Emboss::ajFeattableCopy;
*Bio::Emboss::Feattable::ajFeatUfoRead = *Bio::Emboss::ajFeatUfoRead;
*Bio::Emboss::Feattable::ajFeatNew = *Bio::Emboss::ajFeatNew;
*Bio::Emboss::Feattable::ajFeatNewII = *Bio::Emboss::ajFeatNewII;
*Bio::Emboss::Feattable::ajFeatNewProt = *Bio::Emboss::ajFeatNewProt;
*Bio::Emboss::Feattable::ajFeatSortByEnd = *Bio::Emboss::ajFeatSortByEnd;
*Bio::Emboss::Feattable::ajFeatSortByStart = *Bio::Emboss::ajFeatSortByStart;
*Bio::Emboss::Feattable::ajFeatSortByType = *Bio::Emboss::ajFeatSortByType;
*Bio::Emboss::Feattable::ajFeattableAdd = *Bio::Emboss::ajFeattableAdd;
*Bio::Emboss::Feattable::ajFeattableBegin = *Bio::Emboss::ajFeattableBegin;
*Bio::Emboss::Feattable::ajFeattableClear = *Bio::Emboss::ajFeattableClear;
*Bio::Emboss::Feattable::ajFeattableDel = *Bio::Emboss::ajFeattableDel;
*Bio::Emboss::Feattable::ajFeattableEnd = *Bio::Emboss::ajFeattableEnd;
*Bio::Emboss::Feattable::ajFeattableGetName = *Bio::Emboss::ajFeattableGetName;
*Bio::Emboss::Feattable::ajFeattableIsNuc = *Bio::Emboss::ajFeattableIsNuc;
*Bio::Emboss::Feattable::ajFeattableIsProt = *Bio::Emboss::ajFeattableIsProt;
*Bio::Emboss::Feattable::ajFeattableLen = *Bio::Emboss::ajFeattableLen;
*Bio::Emboss::Feattable::ajFeattablePos = *Bio::Emboss::ajFeattablePos;
*Bio::Emboss::Feattable::ajFeattablePosI = *Bio::Emboss::ajFeattablePosI;
*Bio::Emboss::Feattable::ajFeattableReverse = *Bio::Emboss::ajFeattableReverse;
*Bio::Emboss::Feattable::ajFeattableSetDna = *Bio::Emboss::ajFeattableSetDna;
*Bio::Emboss::Feattable::ajFeattableSetProt = *Bio::Emboss::ajFeattableSetProt;
*Bio::Emboss::Feattable::ajFeattableSetRange = *Bio::Emboss::ajFeattableSetRange;
*Bio::Emboss::Feattable::ajFeattableSize = *Bio::Emboss::ajFeattableSize;
*Bio::Emboss::Feattable::ajFeattableTrace = *Bio::Emboss::ajFeattableTrace;
*Bio::Emboss::Feattable::ajFeattableWriteDdbj = *Bio::Emboss::ajFeattableWriteDdbj;
*Bio::Emboss::Feattable::ajFeattableWriteEmbl = *Bio::Emboss::ajFeattableWriteEmbl;
*Bio::Emboss::Feattable::ajFeattableWriteGenbank = *Bio::Emboss::ajFeattableWriteGenbank;
*Bio::Emboss::Feattable::ajFeattableWriteGff = *Bio::Emboss::ajFeattableWriteGff;
*Bio::Emboss::Feattable::ajFeattableWritePir = *Bio::Emboss::ajFeattableWritePir;
*Bio::Emboss::Feattable::ajFeattableWriteSwiss = *Bio::Emboss::ajFeattableWriteSwiss;
*Bio::Emboss::Feattable::ajFeatUfoWrite = *Bio::Emboss::ajFeatUfoWrite;

*Bio::Emboss::Feature::ajFeatIsChild = *Bio::Emboss::ajFeatIsChild;
*Bio::Emboss::Feature::ajFeatIsCompMult = *Bio::Emboss::ajFeatIsCompMult;
*Bio::Emboss::Feature::ajFeatCopy = *Bio::Emboss::ajFeatCopy;
*Bio::Emboss::Feature::ajFeatDel = *Bio::Emboss::ajFeatDel;
*Bio::Emboss::Feature::ajFeatGetEnd = *Bio::Emboss::ajFeatGetEnd;
*Bio::Emboss::Feature::ajFeatGetForward = *Bio::Emboss::ajFeatGetForward;
*Bio::Emboss::Feature::ajFeatGetFrame = *Bio::Emboss::ajFeatGetFrame;
*Bio::Emboss::Feature::ajFeatGetNote = *Bio::Emboss::ajFeatGetNote;
*Bio::Emboss::Feature::ajFeatGetNoteI = *Bio::Emboss::ajFeatGetNoteI;
*Bio::Emboss::Feature::ajFeatGetStart = *Bio::Emboss::ajFeatGetStart;
*Bio::Emboss::Feature::ajFeatGetTag = *Bio::Emboss::ajFeatGetTag;
*Bio::Emboss::Feature::ajFeatGetType = *Bio::Emboss::ajFeatGetType;
*Bio::Emboss::Feature::ajFeatIsLocal = *Bio::Emboss::ajFeatIsLocal;
*Bio::Emboss::Feature::ajFeatIsLocalRange = *Bio::Emboss::ajFeatIsLocalRange;
*Bio::Emboss::Feature::ajFeatIsMultiple = *Bio::Emboss::ajFeatIsMultiple;
*Bio::Emboss::Feature::ajFeatReverse = *Bio::Emboss::ajFeatReverse;
*Bio::Emboss::Feature::ajFeatSetDesc = *Bio::Emboss::ajFeatSetDesc;
*Bio::Emboss::Feature::ajFeatSetDescApp = *Bio::Emboss::ajFeatSetDescApp;
*Bio::Emboss::Feature::ajFeatTagAdd = *Bio::Emboss::ajFeatTagAdd;
*Bio::Emboss::Feature::ajFeatTagAddC = *Bio::Emboss::ajFeatTagAddC;
*Bio::Emboss::Feature::ajFeatTagAddCC = *Bio::Emboss::ajFeatTagAddCC;
*Bio::Emboss::Feature::ajFeatTagIter = *Bio::Emboss::ajFeatTagIter;
*Bio::Emboss::Feature::ajFeatTagSet = *Bio::Emboss::ajFeatTagSet;
*Bio::Emboss::Feature::ajFeatTagSetC = *Bio::Emboss::ajFeatTagSetC;
*Bio::Emboss::Feature::ajFeatTagTrace = *Bio::Emboss::ajFeatTagTrace;
*Bio::Emboss::Feature::ajFeatTrace = *Bio::Emboss::ajFeatTrace;

*Bio::Emboss::File::ajAcdPrintType = *Bio::Emboss::ajAcdPrintType;
*Bio::Emboss::File::ajFileBuffNewFile = *Bio::Emboss::ajFileBuffNewFile;
*Bio::Emboss::File::ajFileClose = *Bio::Emboss::ajFileClose;
*Bio::Emboss::File::ajFileFp = *Bio::Emboss::ajFileFp;
*Bio::Emboss::File::ajFileGetName = *Bio::Emboss::ajFileGetName;
*Bio::Emboss::File::ajFileGets = *Bio::Emboss::ajFileGets;
*Bio::Emboss::File::ajFileGetsL = *Bio::Emboss::ajFileGetsL;
*Bio::Emboss::File::ajFileGetsTrim = *Bio::Emboss::ajFileGetsTrim;
*Bio::Emboss::File::ajFileGetsTrimL = *Bio::Emboss::ajFileGetsTrimL;
*Bio::Emboss::File::ajFileName = *Bio::Emboss::ajFileName;
*Bio::Emboss::File::ajFileOutHeader = *Bio::Emboss::ajFileOutHeader;
*Bio::Emboss::File::ajFileOutClose = *Bio::Emboss::ajFileOutClose;
*Bio::Emboss::File::ajFileNext = *Bio::Emboss::ajFileNext;
*Bio::Emboss::File::ajFileReopen = *Bio::Emboss::ajFileReopen;
*Bio::Emboss::File::ajFileReadLine = *Bio::Emboss::ajFileReadLine;
*Bio::Emboss::File::ajFileReadUint = *Bio::Emboss::ajFileReadUint;
*Bio::Emboss::File::ajFileSeek = *Bio::Emboss::ajFileSeek;
*Bio::Emboss::File::ajFileStderr = *Bio::Emboss::ajFileStderr;
*Bio::Emboss::File::ajFileStdin = *Bio::Emboss::ajFileStdin;
*Bio::Emboss::File::ajFileStdout = *Bio::Emboss::ajFileStdout;
*Bio::Emboss::File::ajFileTell = *Bio::Emboss::ajFileTell;
*Bio::Emboss::File::ajFileTrace = *Bio::Emboss::ajFileTrace;
*Bio::Emboss::File::ajFileUnbuffer = *Bio::Emboss::ajFileUnbuffer;
*Bio::Emboss::File::ajFileWrite = *Bio::Emboss::ajFileWrite;
*Bio::Emboss::File::ajFileWriteByte = *Bio::Emboss::ajFileWriteByte;
*Bio::Emboss::File::ajFileWriteChar = *Bio::Emboss::ajFileWriteChar;
*Bio::Emboss::File::ajFileWriteInt2 = *Bio::Emboss::ajFileWriteInt2;
*Bio::Emboss::File::ajFileWriteInt4 = *Bio::Emboss::ajFileWriteInt4;
*Bio::Emboss::File::ajFileWriteInt8 = *Bio::Emboss::ajFileWriteInt8;
*Bio::Emboss::File::ajFileWriteStr = *Bio::Emboss::ajFileWriteStr;
*Bio::Emboss::File::ajNamPrintDbAttr = *Bio::Emboss::ajNamPrintDbAttr;
*Bio::Emboss::File::ajReportPrintFormat = *Bio::Emboss::ajReportPrintFormat;
*Bio::Emboss::File::ajSeqABIGetBaseOffset = *Bio::Emboss::ajSeqABIGetBaseOffset;
*Bio::Emboss::File::ajSeqABIGetBasePosition = *Bio::Emboss::ajSeqABIGetBasePosition;
*Bio::Emboss::File::ajSeqABIGetBasePosOffset = *Bio::Emboss::ajSeqABIGetBasePosOffset;
*Bio::Emboss::File::ajSeqABIGetBaseSpace = *Bio::Emboss::ajSeqABIGetBaseSpace;
*Bio::Emboss::File::ajSeqABIGetData = *Bio::Emboss::ajSeqABIGetData;
*Bio::Emboss::File::ajSeqABIGetFWO = *Bio::Emboss::ajSeqABIGetFWO;
*Bio::Emboss::File::ajSeqABIGetNBase = *Bio::Emboss::ajSeqABIGetNBase;
*Bio::Emboss::File::ajSeqABIGetNData = *Bio::Emboss::ajSeqABIGetNData;
*Bio::Emboss::File::ajSeqABIGetPrimerOffset = *Bio::Emboss::ajSeqABIGetPrimerOffset;
*Bio::Emboss::File::ajSeqABIGetPrimerPosition = *Bio::Emboss::ajSeqABIGetPrimerPosition;
*Bio::Emboss::File::ajSeqABIGetSignal = *Bio::Emboss::ajSeqABIGetSignal;
*Bio::Emboss::File::ajSeqABIGetTraceOffset = *Bio::Emboss::ajSeqABIGetTraceOffset;
*Bio::Emboss::File::ajSeqABIMachineName = *Bio::Emboss::ajSeqABIMachineName;
*Bio::Emboss::File::ajSeqABIReadSeq = *Bio::Emboss::ajSeqABIReadSeq;
*Bio::Emboss::File::ajSeqABISampleName = *Bio::Emboss::ajSeqABISampleName;
*Bio::Emboss::File::ajSeqABITest = *Bio::Emboss::ajSeqABITest;
*Bio::Emboss::File::ajSeqPrintAccess = *Bio::Emboss::ajSeqPrintAccess;
*Bio::Emboss::File::ajSeqPrintInFormat = *Bio::Emboss::ajSeqPrintInFormat;
*Bio::Emboss::File::ajSeqPrintType = *Bio::Emboss::ajSeqPrintType;
*Bio::Emboss::File::ajSeqoutNewF = *Bio::Emboss::ajSeqoutNewF;
*Bio::Emboss::File::ajSeqPrintOutFormat = *Bio::Emboss::ajSeqPrintOutFormat;
*Bio::Emboss::File::ajSeqWriteXyz = *Bio::Emboss::ajSeqWriteXyz;
*Bio::Emboss::File::ajSssWriteXyz = *Bio::Emboss::ajSssWriteXyz;
*Bio::Emboss::File::ajXyzPdbtospRead = *Bio::Emboss::ajXyzPdbtospRead;
*Bio::Emboss::File::ajXyzPdbtospReadC = *Bio::Emboss::ajXyzPdbtospReadC;
*Bio::Emboss::File::ajXyzPdbtospReadAll = *Bio::Emboss::ajXyzPdbtospReadAll;
*Bio::Emboss::File::ajXyzPdbWriteAll = *Bio::Emboss::ajXyzPdbWriteAll;
*Bio::Emboss::File::ajXyzPdbWriteDomain = *Bio::Emboss::ajXyzPdbWriteDomain;
*Bio::Emboss::File::ajXyzCpdbRead = *Bio::Emboss::ajXyzCpdbRead;
*Bio::Emboss::File::ajXyzCpdbReadFirstModel = *Bio::Emboss::ajXyzCpdbReadFirstModel;
*Bio::Emboss::File::ajXyzCpdbReadOld = *Bio::Emboss::ajXyzCpdbReadOld;
*Bio::Emboss::File::ajXyzCpdbWriteAll = *Bio::Emboss::ajXyzCpdbWriteAll;
*Bio::Emboss::File::ajXyzCpdbWriteDomain = *Bio::Emboss::ajXyzCpdbWriteDomain;
*Bio::Emboss::File::ajXyzScopRead = *Bio::Emboss::ajXyzScopRead;
*Bio::Emboss::File::ajXyzScopReadC = *Bio::Emboss::ajXyzScopReadC;
*Bio::Emboss::File::ajXyzScopReadAll = *Bio::Emboss::ajXyzScopReadAll;
*Bio::Emboss::File::ajXyzScopWrite = *Bio::Emboss::ajXyzScopWrite;
*Bio::Emboss::File::ajXyzScopclaRead = *Bio::Emboss::ajXyzScopclaRead;
*Bio::Emboss::File::ajXyzScopclaReadC = *Bio::Emboss::ajXyzScopclaReadC;
*Bio::Emboss::File::ajXyzScopdesRead = *Bio::Emboss::ajXyzScopdesRead;
*Bio::Emboss::File::ajXyzScopdesReadC = *Bio::Emboss::ajXyzScopdesReadC;
*Bio::Emboss::File::ajXyzHitlistRead = *Bio::Emboss::ajXyzHitlistRead;
*Bio::Emboss::File::ajXyzHitlistReadNode = *Bio::Emboss::ajXyzHitlistReadNode;
*Bio::Emboss::File::ajXyzHitlistReadFam = *Bio::Emboss::ajXyzHitlistReadFam;
*Bio::Emboss::File::ajXyzHitlistReadSfam = *Bio::Emboss::ajXyzHitlistReadSfam;
*Bio::Emboss::File::ajXyzHitlistReadFold = *Bio::Emboss::ajXyzHitlistReadFold;
*Bio::Emboss::File::ajXyzHitlistWrite = *Bio::Emboss::ajXyzHitlistWrite;
*Bio::Emboss::File::ajXyzPrintPdbSeqresChain = *Bio::Emboss::ajXyzPrintPdbSeqresChain;
*Bio::Emboss::File::ajXyzPrintPdbSeqresDomain = *Bio::Emboss::ajXyzPrintPdbSeqresDomain;
*Bio::Emboss::File::ajXyzPrintPdbAtomChain = *Bio::Emboss::ajXyzPrintPdbAtomChain;
*Bio::Emboss::File::ajXyzPrintPdbAtomDomain = *Bio::Emboss::ajXyzPrintPdbAtomDomain;
*Bio::Emboss::File::ajXyzPrintPdbHeterogen = *Bio::Emboss::ajXyzPrintPdbHeterogen;
*Bio::Emboss::File::ajXyzPrintPdbText = *Bio::Emboss::ajXyzPrintPdbText;
*Bio::Emboss::File::ajXyzPrintPdbHeader = *Bio::Emboss::ajXyzPrintPdbHeader;
*Bio::Emboss::File::ajXyzPrintPdbHeaderScop = *Bio::Emboss::ajXyzPrintPdbHeaderScop;
*Bio::Emboss::File::ajXyzPrintPdbTitle = *Bio::Emboss::ajXyzPrintPdbTitle;
*Bio::Emboss::File::ajXyzPrintPdbCompnd = *Bio::Emboss::ajXyzPrintPdbCompnd;
*Bio::Emboss::File::ajXyzPrintPdbSource = *Bio::Emboss::ajXyzPrintPdbSource;
*Bio::Emboss::File::ajXyzPrintPdbEmptyRemark = *Bio::Emboss::ajXyzPrintPdbEmptyRemark;
*Bio::Emboss::File::ajXyzPrintPdbResolution = *Bio::Emboss::ajXyzPrintPdbResolution;
*Bio::Emboss::File::ajXyzScopalgRead = *Bio::Emboss::ajXyzScopalgRead;
*Bio::Emboss::File::ajXyzScopalgWrite = *Bio::Emboss::ajXyzScopalgWrite;
*Bio::Emboss::File::ajXyzCmapRead = *Bio::Emboss::ajXyzCmapRead;
*Bio::Emboss::File::ajXyzCmapReadC = *Bio::Emboss::ajXyzCmapReadC;
*Bio::Emboss::File::ajXyzCmapReadI = *Bio::Emboss::ajXyzCmapReadI;
*Bio::Emboss::File::ajXyzVdwallRead = *Bio::Emboss::ajXyzVdwallRead;
*Bio::Emboss::File::ajXyzSignatureRead = *Bio::Emboss::ajXyzSignatureRead;
*Bio::Emboss::File::ajXyzSignatureWrite = *Bio::Emboss::ajXyzSignatureWrite;
*Bio::Emboss::File::ajXyzSignatureHitsWrite = *Bio::Emboss::ajXyzSignatureHitsWrite;
*Bio::Emboss::File::ajXyzSignatureAlignWrite = *Bio::Emboss::ajXyzSignatureAlignWrite;
*Bio::Emboss::File::ajXyzHetRawRead = *Bio::Emboss::ajXyzHetRawRead;
*Bio::Emboss::File::ajXyzHetRead = *Bio::Emboss::ajXyzHetRead;
*Bio::Emboss::File::ajXyzHetWrite = *Bio::Emboss::ajXyzHetWrite;
*Bio::Emboss::File::embGrpOutputGroupsList = *Bio::Emboss::embGrpOutputGroupsList;
*Bio::Emboss::File::embGrpOutputProgsList = *Bio::Emboss::embGrpOutputProgsList;
*Bio::Emboss::File::ajGraphPrintType = *Bio::Emboss::ajGraphPrintType;

*Bio::Emboss::FileBuff::ajFileBuffClear = *Bio::Emboss::ajFileBuffClear;
*Bio::Emboss::FileBuff::ajFileBuffDel = *Bio::Emboss::ajFileBuffDel;
*Bio::Emboss::FileBuff::ajFileBuffEmpty = *Bio::Emboss::ajFileBuffEmpty;
*Bio::Emboss::FileBuff::ajFileBuffEnd = *Bio::Emboss::ajFileBuffEnd;
*Bio::Emboss::FileBuff::ajFileBuffEof = *Bio::Emboss::ajFileBuffEof;
*Bio::Emboss::FileBuff::ajFileBuffFile = *Bio::Emboss::ajFileBuffFile;
*Bio::Emboss::FileBuff::ajFileBuffFix = *Bio::Emboss::ajFileBuffFix;
*Bio::Emboss::FileBuff::ajFileBuffFp = *Bio::Emboss::ajFileBuffFp;
*Bio::Emboss::FileBuff::ajFileBuffFreeClear = *Bio::Emboss::ajFileBuffFreeClear;
*Bio::Emboss::FileBuff::ajFileBuffGet = *Bio::Emboss::ajFileBuffGet;
*Bio::Emboss::FileBuff::ajFileBuffGetL = *Bio::Emboss::ajFileBuffGetL;
*Bio::Emboss::FileBuff::ajFileBuffGetStore = *Bio::Emboss::ajFileBuffGetStore;
*Bio::Emboss::FileBuff::ajFileBuffLoad = *Bio::Emboss::ajFileBuffLoad;
*Bio::Emboss::FileBuff::ajFileBuffLoadC = *Bio::Emboss::ajFileBuffLoadC;
*Bio::Emboss::FileBuff::ajFileBuffLoadS = *Bio::Emboss::ajFileBuffLoadS;
*Bio::Emboss::FileBuff::ajFileBuffNobuff = *Bio::Emboss::ajFileBuffNobuff;
*Bio::Emboss::FileBuff::ajFileBuffReset = *Bio::Emboss::ajFileBuffReset;
*Bio::Emboss::FileBuff::ajFileBuffResetPos = *Bio::Emboss::ajFileBuffResetPos;
*Bio::Emboss::FileBuff::ajFileBuffSetFile = *Bio::Emboss::ajFileBuffSetFile;
*Bio::Emboss::FileBuff::ajFileBuffStripHtml = *Bio::Emboss::ajFileBuffStripHtml;
*Bio::Emboss::FileBuff::ajFileBuffStripSrs = *Bio::Emboss::ajFileBuffStripSrs;
*Bio::Emboss::FileBuff::ajFileBuffTrace = *Bio::Emboss::ajFileBuffTrace;
*Bio::Emboss::FileBuff::ajFileBuffTraceFull = *Bio::Emboss::ajFileBuffTraceFull;

*Bio::Emboss::Graph::ajGraphInitSeq = *Bio::Emboss::ajGraphInitSeq;
*Bio::Emboss::Graph::ajGraphObjAddLine = *Bio::Emboss::ajGraphObjAddLine;
*Bio::Emboss::Graph::ajGraphObjAddRect = *Bio::Emboss::ajGraphObjAddRect;
*Bio::Emboss::Graph::ajGraphObjAddText = *Bio::Emboss::ajGraphObjAddText;
*Bio::Emboss::Graph::ajGraphObjDel = *Bio::Emboss::ajGraphObjDel;
*Bio::Emboss::Graph::ajGraphOpen = *Bio::Emboss::ajGraphOpen;
*Bio::Emboss::Graph::ajGraphOpenPlot = *Bio::Emboss::ajGraphOpenPlot;
*Bio::Emboss::Graph::ajGraphOpenWin = *Bio::Emboss::ajGraphOpenWin;
*Bio::Emboss::Graph::ajGraphSet = *Bio::Emboss::ajGraphSet;
*Bio::Emboss::Graph::ajGraphSetDevice = *Bio::Emboss::ajGraphSetDevice;
*Bio::Emboss::Graph::ajGraphSetMulti = *Bio::Emboss::ajGraphSetMulti;
*Bio::Emboss::Graph::ajGraphSetName = *Bio::Emboss::ajGraphSetName;
*Bio::Emboss::Graph::ajGraphTrace = *Bio::Emboss::ajGraphTrace;
*Bio::Emboss::Graph::ajGraphTraceInt = *Bio::Emboss::ajGraphTraceInt;
*Bio::Emboss::Graph::ajGraphxyAddGraph = *Bio::Emboss::ajGraphxyAddGraph;
*Bio::Emboss::Graph::ajGraphxyReplaceGraph = *Bio::Emboss::ajGraphxyReplaceGraph;
*Bio::Emboss::Graph::ajGraphxyDel = *Bio::Emboss::ajGraphxyDel;
*Bio::Emboss::Graph::ajGraphxyDisplay = *Bio::Emboss::ajGraphxyDisplay;
*Bio::Emboss::Graph::ajGraphxyCheckMaxMin = *Bio::Emboss::ajGraphxyCheckMaxMin;
*Bio::Emboss::Graph::ajGraphxySet = *Bio::Emboss::ajGraphxySet;
*Bio::Emboss::Graph::ajGraphxySetCirclePoints = *Bio::Emboss::ajGraphxySetCirclePoints;
*Bio::Emboss::Graph::ajGraphxySetFlag = *Bio::Emboss::ajGraphxySetFlag;
*Bio::Emboss::Graph::ajGraphxySetGaps = *Bio::Emboss::ajGraphxySetGaps;
*Bio::Emboss::Graph::ajGraphxySetJoinPoints = *Bio::Emboss::ajGraphxySetJoinPoints;
*Bio::Emboss::Graph::ajGraphxySetMaxMin = *Bio::Emboss::ajGraphxySetMaxMin;
*Bio::Emboss::Graph::ajGraphxySetOut = *Bio::Emboss::ajGraphxySetOut;
*Bio::Emboss::Graph::ajGraphxySetOutC = *Bio::Emboss::ajGraphxySetOutC;
*Bio::Emboss::Graph::ajGraphxySetOverLap = *Bio::Emboss::ajGraphxySetOverLap;
*Bio::Emboss::Graph::ajGraphxySetSubtitleDo = *Bio::Emboss::ajGraphxySetSubtitleDo;
*Bio::Emboss::Graph::ajGraphxySetTitleDo = *Bio::Emboss::ajGraphxySetTitleDo;
*Bio::Emboss::Graph::ajGraphxySetXBottom = *Bio::Emboss::ajGraphxySetXBottom;
*Bio::Emboss::Graph::ajGraphxySetXLabelTop = *Bio::Emboss::ajGraphxySetXLabelTop;
*Bio::Emboss::Graph::ajGraphxySetXTick = *Bio::Emboss::ajGraphxySetXTick;
*Bio::Emboss::Graph::ajGraphxySetXTop = *Bio::Emboss::ajGraphxySetXTop;
*Bio::Emboss::Graph::ajGraphxySetXEnd = *Bio::Emboss::ajGraphxySetXEnd;
*Bio::Emboss::Graph::ajGraphxySetXGrid = *Bio::Emboss::ajGraphxySetXGrid;
*Bio::Emboss::Graph::ajGraphxySetXInvTicks = *Bio::Emboss::ajGraphxySetXInvTicks;
*Bio::Emboss::Graph::ajGraphxySetXLabel = *Bio::Emboss::ajGraphxySetXLabel;
*Bio::Emboss::Graph::ajGraphxySetXRangeII = *Bio::Emboss::ajGraphxySetXRangeII;
*Bio::Emboss::Graph::ajGraphxySetXStart = *Bio::Emboss::ajGraphxySetXStart;
*Bio::Emboss::Graph::ajGraphxySetYLabelLeft = *Bio::Emboss::ajGraphxySetYLabelLeft;
*Bio::Emboss::Graph::ajGraphxySetYLeft = *Bio::Emboss::ajGraphxySetYLeft;
*Bio::Emboss::Graph::ajGraphxySetYRight = *Bio::Emboss::ajGraphxySetYRight;
*Bio::Emboss::Graph::ajGraphxySetYTick = *Bio::Emboss::ajGraphxySetYTick;
*Bio::Emboss::Graph::ajGraphxySetYEnd = *Bio::Emboss::ajGraphxySetYEnd;
*Bio::Emboss::Graph::ajGraphxySetYGrid = *Bio::Emboss::ajGraphxySetYGrid;
*Bio::Emboss::Graph::ajGraphxySetYInvTicks = *Bio::Emboss::ajGraphxySetYInvTicks;
*Bio::Emboss::Graph::ajGraphxySetYLabel = *Bio::Emboss::ajGraphxySetYLabel;
*Bio::Emboss::Graph::ajGraphxySetYRangeII = *Bio::Emboss::ajGraphxySetYRangeII;
*Bio::Emboss::Graph::ajGraphxySetYStart = *Bio::Emboss::ajGraphxySetYStart;
*Bio::Emboss::Graph::ajGraphxySubtitle = *Bio::Emboss::ajGraphxySubtitle;
*Bio::Emboss::Graph::ajGraphxySubtitleC = *Bio::Emboss::ajGraphxySubtitleC;
*Bio::Emboss::Graph::ajGraphxyTitle = *Bio::Emboss::ajGraphxyTitle;
*Bio::Emboss::Graph::ajGraphxyTitleC = *Bio::Emboss::ajGraphxyTitleC;
*Bio::Emboss::Graph::ajGraphxyXtitle = *Bio::Emboss::ajGraphxyXtitle;
*Bio::Emboss::Graph::ajGraphxyXtitleC = *Bio::Emboss::ajGraphxyXtitleC;
*Bio::Emboss::Graph::ajGraphxyYtitle = *Bio::Emboss::ajGraphxyYtitle;
*Bio::Emboss::Graph::ajGraphxyYtitleC = *Bio::Emboss::ajGraphxyYtitleC;
*Bio::Emboss::Graph::ajGraphClear = *Bio::Emboss::ajGraphClear;
*Bio::Emboss::Graph::ajGraphGetSubTitle = *Bio::Emboss::ajGraphGetSubTitle;
*Bio::Emboss::Graph::ajGraphGetSubTitleC = *Bio::Emboss::ajGraphGetSubTitleC;
*Bio::Emboss::Graph::ajGraphGetTitle = *Bio::Emboss::ajGraphGetTitle;
*Bio::Emboss::Graph::ajGraphGetTitleC = *Bio::Emboss::ajGraphGetTitleC;
*Bio::Emboss::Graph::ajGraphGetXTitle = *Bio::Emboss::ajGraphGetXTitle;
*Bio::Emboss::Graph::ajGraphGetXTitleC = *Bio::Emboss::ajGraphGetXTitleC;
*Bio::Emboss::Graph::ajGraphGetYTitle = *Bio::Emboss::ajGraphGetYTitle;
*Bio::Emboss::Graph::ajGraphGetYTitleC = *Bio::Emboss::ajGraphGetYTitleC;
*Bio::Emboss::Graph::ajGraphIsData = *Bio::Emboss::ajGraphIsData;
*Bio::Emboss::Graph::ajGraphAddLine = *Bio::Emboss::ajGraphAddLine;
*Bio::Emboss::Graph::ajGraphAddRect = *Bio::Emboss::ajGraphAddRect;
*Bio::Emboss::Graph::ajGraphAddText = *Bio::Emboss::ajGraphAddText;
*Bio::Emboss::Graph::ajGraphDataAdd = *Bio::Emboss::ajGraphDataAdd;
*Bio::Emboss::Graph::ajGraphDataReplace = *Bio::Emboss::ajGraphDataReplace;
*Bio::Emboss::Graph::ajGraphSetFlag = *Bio::Emboss::ajGraphSetFlag;
*Bio::Emboss::Graph::ajGraphSetOut = *Bio::Emboss::ajGraphSetOut;
*Bio::Emboss::Graph::ajGraphSetOutC = *Bio::Emboss::ajGraphSetOutC;
*Bio::Emboss::Graph::ajGraphSetSubTitleDo = *Bio::Emboss::ajGraphSetSubTitleDo;
*Bio::Emboss::Graph::ajGraphSetTitleDo = *Bio::Emboss::ajGraphSetTitleDo;
*Bio::Emboss::Graph::ajGraphSetSubTitle = *Bio::Emboss::ajGraphSetSubTitle;
*Bio::Emboss::Graph::ajGraphSetSubTitleC = *Bio::Emboss::ajGraphSetSubTitleC;
*Bio::Emboss::Graph::ajGraphSetTitle = *Bio::Emboss::ajGraphSetTitle;
*Bio::Emboss::Graph::ajGraphSetTitleC = *Bio::Emboss::ajGraphSetTitleC;
*Bio::Emboss::Graph::ajGraphSetXTitle = *Bio::Emboss::ajGraphSetXTitle;
*Bio::Emboss::Graph::ajGraphSetXTitleC = *Bio::Emboss::ajGraphSetXTitleC;
*Bio::Emboss::Graph::ajGraphSetYTitle = *Bio::Emboss::ajGraphSetYTitle;
*Bio::Emboss::Graph::ajGraphSetYTitleC = *Bio::Emboss::ajGraphSetYTitleC;

*Bio::Emboss::GraphData::ajGraphDataDel = *Bio::Emboss::ajGraphDataDel;
*Bio::Emboss::GraphData::ajGraphDataObjAddLine = *Bio::Emboss::ajGraphDataObjAddLine;
*Bio::Emboss::GraphData::ajGraphDataObjAddRect = *Bio::Emboss::ajGraphDataObjAddRect;
*Bio::Emboss::GraphData::ajGraphDataObjAddText = *Bio::Emboss::ajGraphDataObjAddText;
*Bio::Emboss::GraphData::ajGraphDataxySetMaxMin = *Bio::Emboss::ajGraphDataxySetMaxMin;
*Bio::Emboss::GraphData::ajGraphDataxySetMaxima = *Bio::Emboss::ajGraphDataxySetMaxima;
*Bio::Emboss::GraphData::ajGraphDataxySetTypeC = *Bio::Emboss::ajGraphDataxySetTypeC;
*Bio::Emboss::GraphData::ajGraphDataObjDel = *Bio::Emboss::ajGraphDataObjDel;
*Bio::Emboss::GraphData::ajGraphxyAddDataCalcPtr = *Bio::Emboss::ajGraphxyAddDataCalcPtr;
*Bio::Emboss::GraphData::ajGraphxyAddDataPtrPtr = *Bio::Emboss::ajGraphxyAddDataPtrPtr;
*Bio::Emboss::GraphData::ajGraphxyDataSetSubtitle = *Bio::Emboss::ajGraphxyDataSetSubtitle;
*Bio::Emboss::GraphData::ajGraphxyDataSetSubtitleC = *Bio::Emboss::ajGraphxyDataSetSubtitleC;
*Bio::Emboss::GraphData::ajGraphxyDataSetTitle = *Bio::Emboss::ajGraphxyDataSetTitle;
*Bio::Emboss::GraphData::ajGraphxyDataSetTitleC = *Bio::Emboss::ajGraphxyDataSetTitleC;
*Bio::Emboss::GraphData::ajGraphxyDataSetXtitle = *Bio::Emboss::ajGraphxyDataSetXtitle;
*Bio::Emboss::GraphData::ajGraphxyDataSetXtitleC = *Bio::Emboss::ajGraphxyDataSetXtitleC;
*Bio::Emboss::GraphData::ajGraphxyDataSetYtitle = *Bio::Emboss::ajGraphxyDataSetYtitle;
*Bio::Emboss::GraphData::ajGraphxyDataSetYtitleC = *Bio::Emboss::ajGraphxyDataSetYtitleC;
*Bio::Emboss::GraphData::ajGraphxySetColour = *Bio::Emboss::ajGraphxySetColour;
*Bio::Emboss::GraphData::ajGraphxySetLineType = *Bio::Emboss::ajGraphxySetLineType;

*Bio::Emboss::GraphPlpData::ajGraphPlpDataAddLine = *Bio::Emboss::ajGraphPlpDataAddLine;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataAddRect = *Bio::Emboss::ajGraphPlpDataAddRect;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataAddText = *Bio::Emboss::ajGraphPlpDataAddText;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetMaxMin = *Bio::Emboss::ajGraphPlpDataSetMaxMin;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetMaxima = *Bio::Emboss::ajGraphPlpDataSetMaxima;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetTypeC = *Bio::Emboss::ajGraphPlpDataSetTypeC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataTrace = *Bio::Emboss::ajGraphPlpDataTrace;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataDel = *Bio::Emboss::ajGraphPlpDataDel;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataCalcXY = *Bio::Emboss::ajGraphPlpDataCalcXY;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetXY = *Bio::Emboss::ajGraphPlpDataSetXY;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetSubTitle = *Bio::Emboss::ajGraphPlpDataSetSubTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetSubTitleC = *Bio::Emboss::ajGraphPlpDataSetSubTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetTitle = *Bio::Emboss::ajGraphPlpDataSetTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetTitleC = *Bio::Emboss::ajGraphPlpDataSetTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetXTitle = *Bio::Emboss::ajGraphPlpDataSetXTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetXTitleC = *Bio::Emboss::ajGraphPlpDataSetXTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetYTitle = *Bio::Emboss::ajGraphPlpDataSetYTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetYTitleC = *Bio::Emboss::ajGraphPlpDataSetYTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetColour = *Bio::Emboss::ajGraphPlpDataSetColour;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetLineType = *Bio::Emboss::ajGraphPlpDataSetLineType;

*Bio::Emboss::Het::ajXyzHetDel = *Bio::Emboss::ajXyzHetDel;

*Bio::Emboss::Hetent::ajXyzHetentDel = *Bio::Emboss::ajXyzHetentDel;

*Bio::Emboss::Hist::ajHistCopyData = *Bio::Emboss::ajHistCopyData;
*Bio::Emboss::Hist::ajHistDelete = *Bio::Emboss::ajHistDelete;
*Bio::Emboss::Hist::ajHistDisplay = *Bio::Emboss::ajHistDisplay;
*Bio::Emboss::Hist::ajHistSetBlackandWhite = *Bio::Emboss::ajHistSetBlackandWhite;
*Bio::Emboss::Hist::ajHistSetColour = *Bio::Emboss::ajHistSetColour;
*Bio::Emboss::Hist::ajHistSetMultiTitle = *Bio::Emboss::ajHistSetMultiTitle;
*Bio::Emboss::Hist::ajHistSetMultiTitleC = *Bio::Emboss::ajHistSetMultiTitleC;
*Bio::Emboss::Hist::ajHistSetMultiXTitle = *Bio::Emboss::ajHistSetMultiXTitle;
*Bio::Emboss::Hist::ajHistSetMultiXTitleC = *Bio::Emboss::ajHistSetMultiXTitleC;
*Bio::Emboss::Hist::ajHistSetMultiYTitle = *Bio::Emboss::ajHistSetMultiYTitle;
*Bio::Emboss::Hist::ajHistSetMultiYTitleC = *Bio::Emboss::ajHistSetMultiYTitleC;
*Bio::Emboss::Hist::ajHistSetPattern = *Bio::Emboss::ajHistSetPattern;
*Bio::Emboss::Hist::ajHistSetPtrToData = *Bio::Emboss::ajHistSetPtrToData;
*Bio::Emboss::Hist::ajHistSetTitleC = *Bio::Emboss::ajHistSetTitleC;
*Bio::Emboss::Hist::ajHistSetXAxisC = *Bio::Emboss::ajHistSetXAxisC;
*Bio::Emboss::Hist::ajHistSetYAxisLeftC = *Bio::Emboss::ajHistSetYAxisLeftC;
*Bio::Emboss::Hist::ajHistSetYAxisRightC = *Bio::Emboss::ajHistSetYAxisRightC;

*Bio::Emboss::Hit::ajXyzScophitToHit = *Bio::Emboss::ajXyzScophitToHit;
*Bio::Emboss::Hit::ajXyzHitDel = *Bio::Emboss::ajXyzHitDel;
*Bio::Emboss::Hit::ajXyzHitsOverlap = *Bio::Emboss::ajXyzHitsOverlap;

*Bio::Emboss::Hitidx::ajXyzHitidxDel = *Bio::Emboss::ajXyzHitidxDel;

*Bio::Emboss::Hitlist::ajXyzHitlistDel = *Bio::Emboss::ajXyzHitlistDel;
*Bio::Emboss::Hitlist::ajXyzHitlistClassify = *Bio::Emboss::ajXyzHitlistClassify;
*Bio::Emboss::Hitlist::ajXyzHitlistPriorityHigh = *Bio::Emboss::ajXyzHitlistPriorityHigh;
*Bio::Emboss::Hitlist::ajXyzHitlistPriorityLow = *Bio::Emboss::ajXyzHitlistPriorityLow;

*Bio::Emboss::List::ajFileBuffNewInList = *Bio::Emboss::ajFileBuffNewInList;
*Bio::Emboss::List::ajFileNewInList = *Bio::Emboss::ajFileNewInList;
*Bio::Emboss::List::ajListAppend = *Bio::Emboss::ajListAppend;
*Bio::Emboss::List::ajListCopy = *Bio::Emboss::ajListCopy;
*Bio::Emboss::List::ajListDel = *Bio::Emboss::ajListDel;
*Bio::Emboss::List::ajListFree = *Bio::Emboss::ajListFree;
*Bio::Emboss::List::ajListIter = *Bio::Emboss::ajListIter;
*Bio::Emboss::List::ajListIterBack = *Bio::Emboss::ajListIterBack;
*Bio::Emboss::List::ajListLength = *Bio::Emboss::ajListLength;
*Bio::Emboss::List::ajListPush = *Bio::Emboss::ajListPush;
*Bio::Emboss::List::ajListPushApp = *Bio::Emboss::ajListPushApp;
*Bio::Emboss::List::ajListReverse = *Bio::Emboss::ajListReverse;
*Bio::Emboss::List::ajListstrCopy = *Bio::Emboss::ajListstrCopy;
*Bio::Emboss::List::ajListstrDel = *Bio::Emboss::ajListstrDel;
*Bio::Emboss::List::ajListstrFree = *Bio::Emboss::ajListstrFree;
*Bio::Emboss::List::ajListstrLength = *Bio::Emboss::ajListstrLength;
*Bio::Emboss::List::ajListstrPop = *Bio::Emboss::ajListstrPop;
*Bio::Emboss::List::ajListstrPopEnd = *Bio::Emboss::ajListstrPopEnd;
*Bio::Emboss::List::ajListstrPush = *Bio::Emboss::ajListstrPush;
*Bio::Emboss::List::ajListstrPushApp = *Bio::Emboss::ajListstrPushApp;
*Bio::Emboss::List::ajListstrReverse = *Bio::Emboss::ajListstrReverse;
*Bio::Emboss::List::ajListstrToArray = *Bio::Emboss::ajListstrToArray;
*Bio::Emboss::List::ajListstrTrace = *Bio::Emboss::ajListstrTrace;
*Bio::Emboss::List::ajListTrace = *Bio::Emboss::ajListTrace;
*Bio::Emboss::List::ajListPushList = *Bio::Emboss::ajListPushList;
*Bio::Emboss::List::ajListstrPushList = *Bio::Emboss::ajListstrPushList;
*Bio::Emboss::List::ajListstrClone = *Bio::Emboss::ajListstrClone;
*Bio::Emboss::List::ajListSort = *Bio::Emboss::ajListSort;
*Bio::Emboss::List::ajNamListListDatabases = *Bio::Emboss::ajNamListListDatabases;
*Bio::Emboss::List::ajRangeStrExtractList = *Bio::Emboss::ajRangeStrExtractList;
*Bio::Emboss::List::ajXyzScophitsToHitlist = *Bio::Emboss::ajXyzScophitsToHitlist;
*Bio::Emboss::List::ajXyzScophitListCopy = *Bio::Emboss::ajXyzScophitListCopy;
*Bio::Emboss::List::ajXyzScophitMergeInsertThis = *Bio::Emboss::ajXyzScophitMergeInsertThis;
*Bio::Emboss::List::ajXyzScophitMergeInsertOther = *Bio::Emboss::ajXyzScophitMergeInsertOther;
*Bio::Emboss::List::ajXyzHitlistToScophits = *Bio::Emboss::ajXyzHitlistToScophits;
*Bio::Emboss::List::ajXyzHitlistToThreeScophits = *Bio::Emboss::ajXyzHitlistToThreeScophits;
*Bio::Emboss::List::ajXyzHitlistsWriteFasta = *Bio::Emboss::ajXyzHitlistsWriteFasta;
*Bio::Emboss::List::embGrpGetProgGroups = *Bio::Emboss::embGrpGetProgGroups;
*Bio::Emboss::List::embGrpGroupsListDel = *Bio::Emboss::embGrpGroupsListDel;
*Bio::Emboss::List::embGrpKeySearchProgs = *Bio::Emboss::embGrpKeySearchProgs;
*Bio::Emboss::List::embGrpKeySearchSeeAlso = *Bio::Emboss::embGrpKeySearchSeeAlso;
*Bio::Emboss::List::embGrpSortGroupsList = *Bio::Emboss::embGrpSortGroupsList;
*Bio::Emboss::List::embGrpMakeUnique = *Bio::Emboss::embGrpMakeUnique;
*Bio::Emboss::List::ajGraphInfo = *Bio::Emboss::ajGraphInfo;

*Bio::Emboss::Pdb::ajXyzPdbDel = *Bio::Emboss::ajXyzPdbDel;
*Bio::Emboss::Pdb::ajXyzPdbAtomIndexI = *Bio::Emboss::ajXyzPdbAtomIndexI;
*Bio::Emboss::Pdb::ajXyzPdbAtomIndexC = *Bio::Emboss::ajXyzPdbAtomIndexC;
*Bio::Emboss::Pdb::ajXyzPdbAtomIndexICA = *Bio::Emboss::ajXyzPdbAtomIndexICA;
*Bio::Emboss::Pdb::ajXyzPdbAtomIndexCCA = *Bio::Emboss::ajXyzPdbAtomIndexCCA;

*Bio::Emboss::Pdbtosp::ajXyzPdbtospDel = *Bio::Emboss::ajXyzPdbtospDel;

*Bio::Emboss::Range::ajRangeDefault = *Bio::Emboss::ajRangeDefault;
*Bio::Emboss::Range::ajRangeDel = *Bio::Emboss::ajRangeDel;
*Bio::Emboss::Range::ajRangeGet = *Bio::Emboss::ajRangeGet;
*Bio::Emboss::Range::ajRangeFile = *Bio::Emboss::ajRangeFile;
*Bio::Emboss::Range::ajRangeNumber = *Bio::Emboss::ajRangeNumber;
*Bio::Emboss::Range::ajRangeText = *Bio::Emboss::ajRangeText;
*Bio::Emboss::Range::ajRangeValues = *Bio::Emboss::ajRangeValues;
*Bio::Emboss::Range::ajRangeChange = *Bio::Emboss::ajRangeChange;
*Bio::Emboss::Range::ajRangeBegin = *Bio::Emboss::ajRangeBegin;
*Bio::Emboss::Range::ajRangeOverlaps = *Bio::Emboss::ajRangeOverlaps;
*Bio::Emboss::Range::ajRangeOrdered = *Bio::Emboss::ajRangeOrdered;

*Bio::Emboss::Report::ajReportClose = *Bio::Emboss::ajReportClose;
*Bio::Emboss::Report::ajReportDel = *Bio::Emboss::ajReportDel;
*Bio::Emboss::Report::ajReportOpen = *Bio::Emboss::ajReportOpen;
*Bio::Emboss::Report::ajReportFileAdd = *Bio::Emboss::ajReportFileAdd;
*Bio::Emboss::Report::ajReportSeqName = *Bio::Emboss::ajReportSeqName;
*Bio::Emboss::Report::ajReportSetHeader = *Bio::Emboss::ajReportSetHeader;
*Bio::Emboss::Report::ajReportSetHeaderC = *Bio::Emboss::ajReportSetHeaderC;
*Bio::Emboss::Report::ajReportSetTags = *Bio::Emboss::ajReportSetTags;
*Bio::Emboss::Report::ajReportSetTail = *Bio::Emboss::ajReportSetTail;
*Bio::Emboss::Report::ajReportSetTailC = *Bio::Emboss::ajReportSetTailC;
*Bio::Emboss::Report::ajReportSetType = *Bio::Emboss::ajReportSetType;
*Bio::Emboss::Report::ajReportWriteTail = *Bio::Emboss::ajReportWriteTail;
*Bio::Emboss::Report::ajReportValid = *Bio::Emboss::ajReportValid;
*Bio::Emboss::Report::ajReportWrite = *Bio::Emboss::ajReportWrite;
*Bio::Emboss::Report::ajReportWriteHeader = *Bio::Emboss::ajReportWriteHeader;

*Bio::Emboss::Scop::ajXyzScopDel = *Bio::Emboss::ajXyzScopDel;
*Bio::Emboss::Scop::ajXyzScopToScophit = *Bio::Emboss::ajXyzScopToScophit;
*Bio::Emboss::Scop::ajXyzScopCopy = *Bio::Emboss::ajXyzScopCopy;

*Bio::Emboss::Scopalg::ajXyzScopalgWriteClustal = *Bio::Emboss::ajXyzScopalgWriteClustal;
*Bio::Emboss::Scopalg::ajXyzScopalgWriteClustal2 = *Bio::Emboss::ajXyzScopalgWriteClustal2;
*Bio::Emboss::Scopalg::ajXyzScopalgDel = *Bio::Emboss::ajXyzScopalgDel;
*Bio::Emboss::Scopalg::ajXyzScopalgGetseqs = *Bio::Emboss::ajXyzScopalgGetseqs;

*Bio::Emboss::Scopcla::ajXyzScopclaDel = *Bio::Emboss::ajXyzScopclaDel;

*Bio::Emboss::Scopdes::ajXyzScopdesDel = *Bio::Emboss::ajXyzScopdesDel;

*Bio::Emboss::Scophit::ajXyzScophitDel = *Bio::Emboss::ajXyzScophitDel;
*Bio::Emboss::Scophit::ajXyzScophitsOverlap = *Bio::Emboss::ajXyzScophitsOverlap;
*Bio::Emboss::Scophit::ajXyzScophitsOverlapAcc = *Bio::Emboss::ajXyzScophitsOverlapAcc;
*Bio::Emboss::Scophit::ajXyzScophitCopy = *Bio::Emboss::ajXyzScophitCopy;
*Bio::Emboss::Scophit::ajXyzScophitCheckTarget = *Bio::Emboss::ajXyzScophitCheckTarget;
*Bio::Emboss::Scophit::ajXyzScophitTarget = *Bio::Emboss::ajXyzScophitTarget;
*Bio::Emboss::Scophit::ajXyzScophitTarget2 = *Bio::Emboss::ajXyzScophitTarget2;
*Bio::Emboss::Scophit::ajXyzScophitTargetLowPriority = *Bio::Emboss::ajXyzScophitTargetLowPriority;
*Bio::Emboss::Scophit::ajXyzScophitMerge = *Bio::Emboss::ajXyzScophitMerge;

*Bio::Emboss::Scorealg::ajXyzScorealgDel = *Bio::Emboss::ajXyzScorealgDel;

*Bio::Emboss::Selex::ajSelexDel = *Bio::Emboss::ajSelexDel;

*Bio::Emboss::SelexSQ::ajSelexSQDel = *Bio::Emboss::ajSelexSQDel;

*Bio::Emboss::Selexdata::ajSelexdataDel = *Bio::Emboss::ajSelexdataDel;

*Bio::Emboss::Seq::ajFeattableNewSeq = *Bio::Emboss::ajFeattableNewSeq;
*Bio::Emboss::Seq::ajSeqAssAcc = *Bio::Emboss::ajSeqAssAcc;
*Bio::Emboss::Seq::ajSeqAssAccC = *Bio::Emboss::ajSeqAssAccC;
*Bio::Emboss::Seq::ajSeqAssDesc = *Bio::Emboss::ajSeqAssDesc;
*Bio::Emboss::Seq::ajSeqAssDescC = *Bio::Emboss::ajSeqAssDescC;
*Bio::Emboss::Seq::ajSeqAssEntry = *Bio::Emboss::ajSeqAssEntry;
*Bio::Emboss::Seq::ajSeqAssEntryC = *Bio::Emboss::ajSeqAssEntryC;
*Bio::Emboss::Seq::ajSeqAssFile = *Bio::Emboss::ajSeqAssFile;
*Bio::Emboss::Seq::ajSeqAssFull = *Bio::Emboss::ajSeqAssFull;
*Bio::Emboss::Seq::ajSeqAssFullC = *Bio::Emboss::ajSeqAssFullC;
*Bio::Emboss::Seq::ajSeqAssGi = *Bio::Emboss::ajSeqAssGi;
*Bio::Emboss::Seq::ajSeqAssGiC = *Bio::Emboss::ajSeqAssGiC;
*Bio::Emboss::Seq::ajSeqAssName = *Bio::Emboss::ajSeqAssName;
*Bio::Emboss::Seq::ajSeqAssNameC = *Bio::Emboss::ajSeqAssNameC;
*Bio::Emboss::Seq::ajSeqAssSeq = *Bio::Emboss::ajSeqAssSeq;
*Bio::Emboss::Seq::ajSeqAssSeqC = *Bio::Emboss::ajSeqAssSeqC;
*Bio::Emboss::Seq::ajSeqAssSeqCI = *Bio::Emboss::ajSeqAssSeqCI;
*Bio::Emboss::Seq::ajSeqAssSv = *Bio::Emboss::ajSeqAssSv;
*Bio::Emboss::Seq::ajSeqAssSvC = *Bio::Emboss::ajSeqAssSvC;
*Bio::Emboss::Seq::ajSeqAssUfo = *Bio::Emboss::ajSeqAssUfo;
*Bio::Emboss::Seq::ajSeqAssUfoC = *Bio::Emboss::ajSeqAssUfoC;
*Bio::Emboss::Seq::ajSeqAssUsa = *Bio::Emboss::ajSeqAssUsa;
*Bio::Emboss::Seq::ajSeqAssUsaC = *Bio::Emboss::ajSeqAssUsaC;
*Bio::Emboss::Seq::ajSeqBegin = *Bio::Emboss::ajSeqBegin;
*Bio::Emboss::Seq::ajSeqChar = *Bio::Emboss::ajSeqChar;
*Bio::Emboss::Seq::ajSeqCharCopy = *Bio::Emboss::ajSeqCharCopy;
*Bio::Emboss::Seq::ajSeqCharCopyL = *Bio::Emboss::ajSeqCharCopyL;
*Bio::Emboss::Seq::ajSeqCheckGcg = *Bio::Emboss::ajSeqCheckGcg;
*Bio::Emboss::Seq::ajSeqClear = *Bio::Emboss::ajSeqClear;
*Bio::Emboss::Seq::ajSeqCompOnly = *Bio::Emboss::ajSeqCompOnly;
*Bio::Emboss::Seq::ajSeqCopyFeat = *Bio::Emboss::ajSeqCopyFeat;
*Bio::Emboss::Seq::ajSeqDel = *Bio::Emboss::ajSeqDel;
*Bio::Emboss::Seq::ajSeqEnd = *Bio::Emboss::ajSeqEnd;
*Bio::Emboss::Seq::ajSeqFill = *Bio::Emboss::ajSeqFill;
*Bio::Emboss::Seq::ajSeqGapCount = *Bio::Emboss::ajSeqGapCount;
*Bio::Emboss::Seq::ajSeqGapStandard = *Bio::Emboss::ajSeqGapStandard;
*Bio::Emboss::Seq::ajSeqGetAcc = *Bio::Emboss::ajSeqGetAcc;
*Bio::Emboss::Seq::ajSeqGetDesc = *Bio::Emboss::ajSeqGetDesc;
*Bio::Emboss::Seq::ajSeqGetEntry = *Bio::Emboss::ajSeqGetEntry;
*Bio::Emboss::Seq::ajSeqGetFeat = *Bio::Emboss::ajSeqGetFeat;
*Bio::Emboss::Seq::ajSeqGetGi = *Bio::Emboss::ajSeqGetGi;
*Bio::Emboss::Seq::ajSeqGetName = *Bio::Emboss::ajSeqGetName;
*Bio::Emboss::Seq::ajSeqGetRange = *Bio::Emboss::ajSeqGetRange;
*Bio::Emboss::Seq::ajSeqGetReverse = *Bio::Emboss::ajSeqGetReverse;
*Bio::Emboss::Seq::ajSeqGetSv = *Bio::Emboss::ajSeqGetSv;
*Bio::Emboss::Seq::ajSeqGetUsa = *Bio::Emboss::ajSeqGetUsa;
*Bio::Emboss::Seq::ajSeqIsNuc = *Bio::Emboss::ajSeqIsNuc;
*Bio::Emboss::Seq::ajSeqIsProt = *Bio::Emboss::ajSeqIsProt;
*Bio::Emboss::Seq::ajSeqLen = *Bio::Emboss::ajSeqLen;
*Bio::Emboss::Seq::ajSeqMakeUsa = *Bio::Emboss::ajSeqMakeUsa;
*Bio::Emboss::Seq::ajSeqMod = *Bio::Emboss::ajSeqMod;
*Bio::Emboss::Seq::ajSeqName = *Bio::Emboss::ajSeqName;
*Bio::Emboss::Seq::ajSeqNewS = *Bio::Emboss::ajSeqNewS;
*Bio::Emboss::Seq::ajSeqNum = *Bio::Emboss::ajSeqNum;
*Bio::Emboss::Seq::ajSeqOffset = *Bio::Emboss::ajSeqOffset;
*Bio::Emboss::Seq::ajSeqOffend = *Bio::Emboss::ajSeqOffend;
*Bio::Emboss::Seq::ajSeqPos = *Bio::Emboss::ajSeqPos;
*Bio::Emboss::Seq::ajSeqPosI = *Bio::Emboss::ajSeqPosI;
*Bio::Emboss::Seq::ajSeqReplace = *Bio::Emboss::ajSeqReplace;
*Bio::Emboss::Seq::ajSeqReplaceC = *Bio::Emboss::ajSeqReplaceC;
*Bio::Emboss::Seq::ajSeqReverse = *Bio::Emboss::ajSeqReverse;
*Bio::Emboss::Seq::ajSeqRevOnly = *Bio::Emboss::ajSeqRevOnly;
*Bio::Emboss::Seq::ajSeqSetRange = *Bio::Emboss::ajSeqSetRange;
*Bio::Emboss::Seq::ajSeqStr = *Bio::Emboss::ajSeqStr;
*Bio::Emboss::Seq::ajSeqStrCopy = *Bio::Emboss::ajSeqStrCopy;
*Bio::Emboss::Seq::ajSeqToLower = *Bio::Emboss::ajSeqToLower;
*Bio::Emboss::Seq::ajSeqToUpper = *Bio::Emboss::ajSeqToUpper;
*Bio::Emboss::Seq::ajSeqTrace = *Bio::Emboss::ajSeqTrace;
*Bio::Emboss::Seq::ajSeqTrim = *Bio::Emboss::ajSeqTrim;
*Bio::Emboss::Seq::ajSeqAllRead = *Bio::Emboss::ajSeqAllRead;
*Bio::Emboss::Seq::ajSeqRead = *Bio::Emboss::ajSeqRead;
*Bio::Emboss::Seq::ajSeqGap = *Bio::Emboss::ajSeqGap;
*Bio::Emboss::Seq::ajSeqGapLen = *Bio::Emboss::ajSeqGapLen;
*Bio::Emboss::Seq::ajSeqSetNuc = *Bio::Emboss::ajSeqSetNuc;
*Bio::Emboss::Seq::ajSeqSetProt = *Bio::Emboss::ajSeqSetProt;
*Bio::Emboss::Seq::ajSeqType = *Bio::Emboss::ajSeqType;
*Bio::Emboss::Seq::ajTrnNewPep = *Bio::Emboss::ajTrnNewPep;

*Bio::Emboss::SeqCvt::ajSeqCvtDel = *Bio::Emboss::ajSeqCvtDel;
*Bio::Emboss::SeqCvt::ajSeqCvtK = *Bio::Emboss::ajSeqCvtK;
*Bio::Emboss::SeqCvt::ajSeqCvtLen = *Bio::Emboss::ajSeqCvtLen;
*Bio::Emboss::SeqCvt::ajSeqCvtTrace = *Bio::Emboss::ajSeqCvtTrace;

*Bio::Emboss::SeqQuery::ajNamDbData = *Bio::Emboss::ajNamDbData;
*Bio::Emboss::SeqQuery::ajNamDbQuery = *Bio::Emboss::ajNamDbQuery;
*Bio::Emboss::SeqQuery::ajSeqQueryClear = *Bio::Emboss::ajSeqQueryClear;
*Bio::Emboss::SeqQuery::ajSeqQueryDel = *Bio::Emboss::ajSeqQueryDel;
*Bio::Emboss::SeqQuery::ajSeqQueryIs = *Bio::Emboss::ajSeqQueryIs;
*Bio::Emboss::SeqQuery::ajSeqQueryStarclear = *Bio::Emboss::ajSeqQueryStarclear;
*Bio::Emboss::SeqQuery::ajSeqQueryTrace = *Bio::Emboss::ajSeqQueryTrace;
*Bio::Emboss::SeqQuery::ajSeqQueryWild = *Bio::Emboss::ajSeqQueryWild;

*Bio::Emboss::Seqall::ajSeqallBegin = *Bio::Emboss::ajSeqallBegin;
*Bio::Emboss::Seqall::ajSeqallDel = *Bio::Emboss::ajSeqallDel;
*Bio::Emboss::Seqall::ajSeqallEnd = *Bio::Emboss::ajSeqallEnd;
*Bio::Emboss::Seqall::ajSeqallGetName = *Bio::Emboss::ajSeqallGetName;
*Bio::Emboss::Seqall::ajSeqallGetNameSeq = *Bio::Emboss::ajSeqallGetNameSeq;
*Bio::Emboss::Seqall::ajSeqallGetRange = *Bio::Emboss::ajSeqallGetRange;
*Bio::Emboss::Seqall::ajSeqallGetUsa = *Bio::Emboss::ajSeqallGetUsa;
*Bio::Emboss::Seqall::ajSeqallLen = *Bio::Emboss::ajSeqallLen;
*Bio::Emboss::Seqall::ajSeqallNext = *Bio::Emboss::ajSeqallNext;
*Bio::Emboss::Seqall::ajSeqallReverse = *Bio::Emboss::ajSeqallReverse;
*Bio::Emboss::Seqall::ajSeqallSetRange = *Bio::Emboss::ajSeqallSetRange;
*Bio::Emboss::Seqall::ajSeqallToLower = *Bio::Emboss::ajSeqallToLower;
*Bio::Emboss::Seqall::ajSeqallToUpper = *Bio::Emboss::ajSeqallToUpper;

*Bio::Emboss::Seqin::ajSeqinTrace = *Bio::Emboss::ajSeqinTrace;
*Bio::Emboss::Seqin::ajSeqAccessAsis = *Bio::Emboss::ajSeqAccessAsis;
*Bio::Emboss::Seqin::ajSeqAccessFile = *Bio::Emboss::ajSeqAccessFile;
*Bio::Emboss::Seqin::ajSeqAccessOffset = *Bio::Emboss::ajSeqAccessOffset;
*Bio::Emboss::Seqin::ajSeqinClear = *Bio::Emboss::ajSeqinClear;
*Bio::Emboss::Seqin::ajSeqinDel = *Bio::Emboss::ajSeqinDel;
*Bio::Emboss::Seqin::ajSeqinSetNuc = *Bio::Emboss::ajSeqinSetNuc;
*Bio::Emboss::Seqin::ajSeqinSetProt = *Bio::Emboss::ajSeqinSetProt;
*Bio::Emboss::Seqin::ajSeqinSetRange = *Bio::Emboss::ajSeqinSetRange;
*Bio::Emboss::Seqin::ajSeqinUsa = *Bio::Emboss::ajSeqinUsa;

*Bio::Emboss::Seqout::ajSeqAllWrite = *Bio::Emboss::ajSeqAllWrite;
*Bio::Emboss::Seqout::ajSeqFileNewOut = *Bio::Emboss::ajSeqFileNewOut;
*Bio::Emboss::Seqout::ajSeqoutCheckGcg = *Bio::Emboss::ajSeqoutCheckGcg;
*Bio::Emboss::Seqout::ajSeqoutClear = *Bio::Emboss::ajSeqoutClear;
*Bio::Emboss::Seqout::ajSeqoutDel = *Bio::Emboss::ajSeqoutDel;
*Bio::Emboss::Seqout::ajSeqoutOpen = *Bio::Emboss::ajSeqoutOpen;
*Bio::Emboss::Seqout::ajSeqOutSetFormat = *Bio::Emboss::ajSeqOutSetFormat;
*Bio::Emboss::Seqout::ajSeqOutSetFormatC = *Bio::Emboss::ajSeqOutSetFormatC;
*Bio::Emboss::Seqout::ajSeqoutTrace = *Bio::Emboss::ajSeqoutTrace;
*Bio::Emboss::Seqout::ajSeqoutUsa = *Bio::Emboss::ajSeqoutUsa;
*Bio::Emboss::Seqout::ajSeqsetWrite = *Bio::Emboss::ajSeqsetWrite;
*Bio::Emboss::Seqout::ajSeqWrite = *Bio::Emboss::ajSeqWrite;
*Bio::Emboss::Seqout::ajSeqWriteClose = *Bio::Emboss::ajSeqWriteClose;

*Bio::Emboss::Seqset::ajSeqsetBegin = *Bio::Emboss::ajSeqsetBegin;
*Bio::Emboss::Seqset::ajSeqsetDel = *Bio::Emboss::ajSeqsetDel;
*Bio::Emboss::Seqset::ajSeqsetEnd = *Bio::Emboss::ajSeqsetEnd;
*Bio::Emboss::Seqset::ajSeqsetFill = *Bio::Emboss::ajSeqsetFill;
*Bio::Emboss::Seqset::ajSeqsetGetFormat = *Bio::Emboss::ajSeqsetGetFormat;
*Bio::Emboss::Seqset::ajSeqsetGetName = *Bio::Emboss::ajSeqsetGetName;
*Bio::Emboss::Seqset::ajSeqsetGetRange = *Bio::Emboss::ajSeqsetGetRange;
*Bio::Emboss::Seqset::ajSeqsetGetSeq = *Bio::Emboss::ajSeqsetGetSeq;
*Bio::Emboss::Seqset::ajSeqsetGetUsa = *Bio::Emboss::ajSeqsetGetUsa;
*Bio::Emboss::Seqset::ajSeqsetIsDna = *Bio::Emboss::ajSeqsetIsDna;
*Bio::Emboss::Seqset::ajSeqsetIsNuc = *Bio::Emboss::ajSeqsetIsNuc;
*Bio::Emboss::Seqset::ajSeqsetIsProt = *Bio::Emboss::ajSeqsetIsProt;
*Bio::Emboss::Seqset::ajSeqsetIsRna = *Bio::Emboss::ajSeqsetIsRna;
*Bio::Emboss::Seqset::ajSeqsetLen = *Bio::Emboss::ajSeqsetLen;
*Bio::Emboss::Seqset::ajSeqsetName = *Bio::Emboss::ajSeqsetName;
*Bio::Emboss::Seqset::ajSeqsetReverse = *Bio::Emboss::ajSeqsetReverse;
*Bio::Emboss::Seqset::ajSeqsetSeq = *Bio::Emboss::ajSeqsetSeq;
*Bio::Emboss::Seqset::ajSeqsetSetRange = *Bio::Emboss::ajSeqsetSetRange;
*Bio::Emboss::Seqset::ajSeqsetSize = *Bio::Emboss::ajSeqsetSize;
*Bio::Emboss::Seqset::ajSeqsetToLower = *Bio::Emboss::ajSeqsetToLower;
*Bio::Emboss::Seqset::ajSeqsetTotweight = *Bio::Emboss::ajSeqsetTotweight;
*Bio::Emboss::Seqset::ajSeqsetToUpper = *Bio::Emboss::ajSeqsetToUpper;
*Bio::Emboss::Seqset::ajSeqsetWeight = *Bio::Emboss::ajSeqsetWeight;
*Bio::Emboss::Seqset::ajSeqsetApp = *Bio::Emboss::ajSeqsetApp;
*Bio::Emboss::Seqset::ajSeqsetRead = *Bio::Emboss::ajSeqsetRead;
*Bio::Emboss::Seqset::ajSeqsetFromList = *Bio::Emboss::ajSeqsetFromList;
*Bio::Emboss::Seqset::ajSeqsetFromPair = *Bio::Emboss::ajSeqsetFromPair;

*Bio::Emboss::Sigdat::ajXyzSigdatDel = *Bio::Emboss::ajXyzSigdatDel;

*Bio::Emboss::Signature::ajXyzSignatureDel = *Bio::Emboss::ajXyzSignatureDel;
*Bio::Emboss::Signature::ajXyzSignatureCompile = *Bio::Emboss::ajXyzSignatureCompile;
*Bio::Emboss::Signature::ajXyzSignatureAlignSeq = *Bio::Emboss::ajXyzSignatureAlignSeq;
*Bio::Emboss::Signature::ajXyzSignatureAlignSeqall = *Bio::Emboss::ajXyzSignatureAlignSeqall;

*Bio::Emboss::Sigpos::ajXyzSigposDel = *Bio::Emboss::ajXyzSigposDel;

*Bio::Emboss::Stockholm::ajStockholmDel = *Bio::Emboss::ajStockholmDel;

*Bio::Emboss::Stockholmdata::ajStockholmdataDel = *Bio::Emboss::ajStockholmdataDel;

*Bio::Emboss::Str::ajAcdProgramS = *Bio::Emboss::ajAcdProgramS;
*Bio::Emboss::Str::ajFeatGetLocs = *Bio::Emboss::ajFeatGetLocs;
*Bio::Emboss::Str::ajFeatGetTrans = *Bio::Emboss::ajFeatGetTrans;
*Bio::Emboss::Str::ajFeatLocToSeq = *Bio::Emboss::ajFeatLocToSeq;
*Bio::Emboss::Str::ajFeattableNew = *Bio::Emboss::ajFeattableNew;
*Bio::Emboss::Str::ajFeattableNewDna = *Bio::Emboss::ajFeattableNewDna;
*Bio::Emboss::Str::ajFeattableNewProt = *Bio::Emboss::ajFeattableNewProt;
*Bio::Emboss::Str::ajFeattabInNewSS = *Bio::Emboss::ajFeattabInNewSS;
*Bio::Emboss::Str::ajFeattabInNewSSF = *Bio::Emboss::ajFeattabInNewSSF;
*Bio::Emboss::Str::ajFeattabOutNewSSF = *Bio::Emboss::ajFeattabOutNewSSF;
*Bio::Emboss::Str::ajFileBuffNewDC = *Bio::Emboss::ajFileBuffNewDC;
*Bio::Emboss::Str::ajFileBuffNewDF = *Bio::Emboss::ajFileBuffNewDF;
*Bio::Emboss::Str::ajFileBuffNewDW = *Bio::Emboss::ajFileBuffNewDW;
*Bio::Emboss::Str::ajFileBuffNewIn = *Bio::Emboss::ajFileBuffNewIn;
*Bio::Emboss::Str::ajFileBuffNewS = *Bio::Emboss::ajFileBuffNewS;
*Bio::Emboss::Str::ajFileDataDirNew = *Bio::Emboss::ajFileDataDirNew;
*Bio::Emboss::Str::ajFileDataNew = *Bio::Emboss::ajFileDataNew;
*Bio::Emboss::Str::ajFileDataNewWrite = *Bio::Emboss::ajFileDataNewWrite;
*Bio::Emboss::Str::ajFileDir = *Bio::Emboss::ajFileDir;
*Bio::Emboss::Str::ajFileDirFix = *Bio::Emboss::ajFileDirFix;
*Bio::Emboss::Str::ajFileDirUp = *Bio::Emboss::ajFileDirUp;
*Bio::Emboss::Str::ajFileDirPath = *Bio::Emboss::ajFileDirPath;
*Bio::Emboss::Str::ajFileDirTrim = *Bio::Emboss::ajFileDirTrim;
*Bio::Emboss::Str::ajFileFileList = *Bio::Emboss::ajFileFileList;
*Bio::Emboss::Str::ajFileGetwd = *Bio::Emboss::ajFileGetwd;
*Bio::Emboss::Str::ajFileLength = *Bio::Emboss::ajFileLength;
*Bio::Emboss::Str::ajFileNameDirSet = *Bio::Emboss::ajFileNameDirSet;
*Bio::Emboss::Str::ajFileNameDirSetC = *Bio::Emboss::ajFileNameDirSetC;
*Bio::Emboss::Str::ajFileNameExt = *Bio::Emboss::ajFileNameExt;
*Bio::Emboss::Str::ajFileNameExtC = *Bio::Emboss::ajFileNameExtC;
*Bio::Emboss::Str::ajFileNameShorten = *Bio::Emboss::ajFileNameShorten;
*Bio::Emboss::Str::ajFileNameTrim = *Bio::Emboss::ajFileNameTrim;
*Bio::Emboss::Str::ajFileNewApp = *Bio::Emboss::ajFileNewApp;
*Bio::Emboss::Str::ajFileNewDC = *Bio::Emboss::ajFileNewDC;
*Bio::Emboss::Str::ajFileNewDF = *Bio::Emboss::ajFileNewDF;
*Bio::Emboss::Str::ajFileNewDW = *Bio::Emboss::ajFileNewDW;
*Bio::Emboss::Str::ajFileNewIn = *Bio::Emboss::ajFileNewIn;
*Bio::Emboss::Str::ajFileNewInPipe = *Bio::Emboss::ajFileNewInPipe;
*Bio::Emboss::Str::ajFileNewOut = *Bio::Emboss::ajFileNewOut;
*Bio::Emboss::Str::ajFileNewOutD = *Bio::Emboss::ajFileNewOutD;
*Bio::Emboss::Str::ajFileScan = *Bio::Emboss::ajFileScan;
*Bio::Emboss::Str::ajFileStat = *Bio::Emboss::ajFileStat;
*Bio::Emboss::Str::ajFileTestSkip = *Bio::Emboss::ajFileTestSkip;
*Bio::Emboss::Str::ajNamDatabase = *Bio::Emboss::ajNamDatabase;
*Bio::Emboss::Str::ajNamDbDetails = *Bio::Emboss::ajNamDbDetails;
*Bio::Emboss::Str::ajNamDbGetDbalias = *Bio::Emboss::ajNamDbGetDbalias;
*Bio::Emboss::Str::ajNamDbGetUrl = *Bio::Emboss::ajNamDbGetUrl;
*Bio::Emboss::Str::ajNamDbTest = *Bio::Emboss::ajNamDbTest;
*Bio::Emboss::Str::ajNamGetenv = *Bio::Emboss::ajNamGetenv;
*Bio::Emboss::Str::ajNamGetValue = *Bio::Emboss::ajNamGetValue;
*Bio::Emboss::Str::ajNamResolve = *Bio::Emboss::ajNamResolve;
*Bio::Emboss::Str::ajNamRoot = *Bio::Emboss::ajNamRoot;
*Bio::Emboss::Str::ajNamRootBase = *Bio::Emboss::ajNamRootBase;
*Bio::Emboss::Str::ajNamRootInstall = *Bio::Emboss::ajNamRootInstall;
*Bio::Emboss::Str::ajNamRootPack = *Bio::Emboss::ajNamRootPack;
*Bio::Emboss::Str::ajNamRootVersion = *Bio::Emboss::ajNamRootVersion;
*Bio::Emboss::Str::ajRangeStrExtract = *Bio::Emboss::ajRangeStrExtract;
*Bio::Emboss::Str::ajRangeStrStuff = *Bio::Emboss::ajRangeStrStuff;
*Bio::Emboss::Str::ajRangeStrMask = *Bio::Emboss::ajRangeStrMask;
*Bio::Emboss::Str::ajReportFindFormat = *Bio::Emboss::ajReportFindFormat;
*Bio::Emboss::Str::ajReportFormatDefault = *Bio::Emboss::ajReportFormatDefault;
*Bio::Emboss::Str::ajIsAccession = *Bio::Emboss::ajIsAccession;
*Bio::Emboss::Str::ajIsSeqversion = *Bio::Emboss::ajIsSeqversion;
*Bio::Emboss::Str::ajSeqCompOnlyStr = *Bio::Emboss::ajSeqCompOnlyStr;
*Bio::Emboss::Str::ajSeqCount = *Bio::Emboss::ajSeqCount;
*Bio::Emboss::Str::ajSeqCrc = *Bio::Emboss::ajSeqCrc;
*Bio::Emboss::Str::ajSeqGapCountS = *Bio::Emboss::ajSeqGapCountS;
*Bio::Emboss::Str::ajSeqMW = *Bio::Emboss::ajSeqMW;
*Bio::Emboss::Str::ajSeqReverseStr = *Bio::Emboss::ajSeqReverseStr;
*Bio::Emboss::Str::ajSeqFindOutFormat = *Bio::Emboss::ajSeqFindOutFormat;
*Bio::Emboss::Str::ajSeqMethod = *Bio::Emboss::ajSeqMethod;
*Bio::Emboss::Str::ajSeqallFile = *Bio::Emboss::ajSeqallFile;
*Bio::Emboss::Str::ajSeqGetFromUsa = *Bio::Emboss::ajSeqGetFromUsa;
*Bio::Emboss::Str::ajSeqParseFasta = *Bio::Emboss::ajSeqParseFasta;
*Bio::Emboss::Str::ajSeqParseNcbi = *Bio::Emboss::ajSeqParseNcbi;
*Bio::Emboss::Str::ajSeqGapS = *Bio::Emboss::ajSeqGapS;
*Bio::Emboss::Str::ajSeqOutFormatDefault = *Bio::Emboss::ajSeqOutFormatDefault;
*Bio::Emboss::Str::ajSeqOutFormatSingle = *Bio::Emboss::ajSeqOutFormatSingle;
*Bio::Emboss::Str::ajStrFix = *Bio::Emboss::ajStrFix;
*Bio::Emboss::Str::ajStrFixI = *Bio::Emboss::ajStrFixI;
*Bio::Emboss::Str::ajStrFixTestI = *Bio::Emboss::ajStrFixTestI;
*Bio::Emboss::Str::ajStrStr = *Bio::Emboss::ajStrStr;
*Bio::Emboss::Str::ajStrTokenCount = *Bio::Emboss::ajStrTokenCount;
*Bio::Emboss::Str::ajStrTokenCountR = *Bio::Emboss::ajStrTokenCountR;
*Bio::Emboss::Str::ajCharNew = *Bio::Emboss::ajCharNew;
*Bio::Emboss::Str::ajStrApp = *Bio::Emboss::ajStrApp;
*Bio::Emboss::Str::ajStrAppC = *Bio::Emboss::ajStrAppC;
*Bio::Emboss::Str::ajStrAppK = *Bio::Emboss::ajStrAppK;
*Bio::Emboss::Str::ajStrAppKI = *Bio::Emboss::ajStrAppKI;
*Bio::Emboss::Str::ajStrAppSub = *Bio::Emboss::ajStrAppSub;
*Bio::Emboss::Str::ajStrAss = *Bio::Emboss::ajStrAss;
*Bio::Emboss::Str::ajStrAssC = *Bio::Emboss::ajStrAssC;
*Bio::Emboss::Str::ajStrAssCI = *Bio::Emboss::ajStrAssCI;
*Bio::Emboss::Str::ajStrAssCL = *Bio::Emboss::ajStrAssCL;
*Bio::Emboss::Str::ajStrAssI = *Bio::Emboss::ajStrAssI;
*Bio::Emboss::Str::ajStrAssL = *Bio::Emboss::ajStrAssL;
*Bio::Emboss::Str::ajStrAssS = *Bio::Emboss::ajStrAssS;
*Bio::Emboss::Str::ajStrAssSub = *Bio::Emboss::ajStrAssSub;
*Bio::Emboss::Str::ajStrAssSubC = *Bio::Emboss::ajStrAssSubC;
*Bio::Emboss::Str::ajStrBlock = *Bio::Emboss::ajStrBlock;
*Bio::Emboss::Str::ajStrChar = *Bio::Emboss::ajStrChar;
*Bio::Emboss::Str::ajStrCheck = *Bio::Emboss::ajStrCheck;
*Bio::Emboss::Str::ajStrChomp = *Bio::Emboss::ajStrChomp;
*Bio::Emboss::Str::ajStrChompC = *Bio::Emboss::ajStrChompC;
*Bio::Emboss::Str::ajStrChompEnd = *Bio::Emboss::ajStrChompEnd;
*Bio::Emboss::Str::ajStrChop = *Bio::Emboss::ajStrChop;
*Bio::Emboss::Str::ajStrClean = *Bio::Emboss::ajStrClean;
*Bio::Emboss::Str::ajStrCleanWhite = *Bio::Emboss::ajStrCleanWhite;
*Bio::Emboss::Str::ajStrClear = *Bio::Emboss::ajStrClear;
*Bio::Emboss::Str::ajStrCmpC = *Bio::Emboss::ajStrCmpC;
*Bio::Emboss::Str::ajStrCmpCase = *Bio::Emboss::ajStrCmpCase;
*Bio::Emboss::Str::ajStrCmpO = *Bio::Emboss::ajStrCmpO;
*Bio::Emboss::Str::ajStrCmpWild = *Bio::Emboss::ajStrCmpWild;
*Bio::Emboss::Str::ajStrCmpWildC = *Bio::Emboss::ajStrCmpWildC;
*Bio::Emboss::Str::ajStrConvert = *Bio::Emboss::ajStrConvert;
*Bio::Emboss::Str::ajStrConvertCC = *Bio::Emboss::ajStrConvertCC;
*Bio::Emboss::Str::ajStrCopy = *Bio::Emboss::ajStrCopy;
*Bio::Emboss::Str::ajStrCopyC = *Bio::Emboss::ajStrCopyC;
*Bio::Emboss::Str::ajStrCountC = *Bio::Emboss::ajStrCountC;
*Bio::Emboss::Str::ajStrCountK = *Bio::Emboss::ajStrCountK;
*Bio::Emboss::Str::ajStrCut = *Bio::Emboss::ajStrCut;
*Bio::Emboss::Str::ajStrDegap = *Bio::Emboss::ajStrDegap;
*Bio::Emboss::Str::ajStrDel = *Bio::Emboss::ajStrDel;
*Bio::Emboss::Str::ajStrDelim = *Bio::Emboss::ajStrDelim;
*Bio::Emboss::Str::ajStrDelReuse = *Bio::Emboss::ajStrDelReuse;
*Bio::Emboss::Str::ajStrDup = *Bio::Emboss::ajStrDup;
*Bio::Emboss::Str::ajStrFind = *Bio::Emboss::ajStrFind;
*Bio::Emboss::Str::ajStrFindC = *Bio::Emboss::ajStrFindC;
*Bio::Emboss::Str::ajStrFindCase = *Bio::Emboss::ajStrFindCase;
*Bio::Emboss::Str::ajStrFindCaseC = *Bio::Emboss::ajStrFindCaseC;
*Bio::Emboss::Str::ajStrFill = *Bio::Emboss::ajStrFill;
*Bio::Emboss::Str::ajStrFromBool = *Bio::Emboss::ajStrFromBool;
*Bio::Emboss::Str::ajStrFromDouble = *Bio::Emboss::ajStrFromDouble;
*Bio::Emboss::Str::ajStrFromDoubleE = *Bio::Emboss::ajStrFromDoubleE;
*Bio::Emboss::Str::ajStrFromFloat = *Bio::Emboss::ajStrFromFloat;
*Bio::Emboss::Str::ajStrFromInt = *Bio::Emboss::ajStrFromInt;
*Bio::Emboss::Str::ajStrFromLong = *Bio::Emboss::ajStrFromLong;
*Bio::Emboss::Str::ajStrInsert = *Bio::Emboss::ajStrInsert;
*Bio::Emboss::Str::ajStrInsertC = *Bio::Emboss::ajStrInsertC;
*Bio::Emboss::Str::ajStrIsAlnum = *Bio::Emboss::ajStrIsAlnum;
*Bio::Emboss::Str::ajStrIsAlpha = *Bio::Emboss::ajStrIsAlpha;
*Bio::Emboss::Str::ajStrIsBool = *Bio::Emboss::ajStrIsBool;
*Bio::Emboss::Str::ajStrIsDouble = *Bio::Emboss::ajStrIsDouble;
*Bio::Emboss::Str::ajStrIsFloat = *Bio::Emboss::ajStrIsFloat;
*Bio::Emboss::Str::ajStrIsHex = *Bio::Emboss::ajStrIsHex;
*Bio::Emboss::Str::ajStrIsInt = *Bio::Emboss::ajStrIsInt;
*Bio::Emboss::Str::ajStrIsLong = *Bio::Emboss::ajStrIsLong;
*Bio::Emboss::Str::ajStrIsSpace = *Bio::Emboss::ajStrIsSpace;
*Bio::Emboss::Str::ajStrIsWild = *Bio::Emboss::ajStrIsWild;
*Bio::Emboss::Str::ajStrIsWord = *Bio::Emboss::ajStrIsWord;
*Bio::Emboss::Str::ajStrIter = *Bio::Emboss::ajStrIter;
*Bio::Emboss::Str::ajStrIterBack = *Bio::Emboss::ajStrIterBack;
*Bio::Emboss::Str::ajStrJoin = *Bio::Emboss::ajStrJoin;
*Bio::Emboss::Str::ajStrJoinC = *Bio::Emboss::ajStrJoinC;
*Bio::Emboss::Str::ajStrLen = *Bio::Emboss::ajStrLen;
*Bio::Emboss::Str::ajStrMask = *Bio::Emboss::ajStrMask;
*Bio::Emboss::Str::ajStrMatch = *Bio::Emboss::ajStrMatch;
*Bio::Emboss::Str::ajStrMatchC = *Bio::Emboss::ajStrMatchC;
*Bio::Emboss::Str::ajStrMatchCase = *Bio::Emboss::ajStrMatchCase;
*Bio::Emboss::Str::ajStrMatchCaseC = *Bio::Emboss::ajStrMatchCaseC;
*Bio::Emboss::Str::ajStrMatchWild = *Bio::Emboss::ajStrMatchWild;
*Bio::Emboss::Str::ajStrMatchWildC = *Bio::Emboss::ajStrMatchWildC;
*Bio::Emboss::Str::ajStrMatchWord = *Bio::Emboss::ajStrMatchWord;
*Bio::Emboss::Str::ajStrMatchWordC = *Bio::Emboss::ajStrMatchWordC;
*Bio::Emboss::Str::ajStrMod = *Bio::Emboss::ajStrMod;
*Bio::Emboss::Str::ajStrModL = *Bio::Emboss::ajStrModL;
*Bio::Emboss::Str::ajStrNCmpC = *Bio::Emboss::ajStrNCmpC;
*Bio::Emboss::Str::ajStrNCmpO = *Bio::Emboss::ajStrNCmpO;
*Bio::Emboss::Str::ajStrNewS = *Bio::Emboss::ajStrNewS;
*Bio::Emboss::Str::ajStrPos = *Bio::Emboss::ajStrPos;
*Bio::Emboss::Str::ajStrPosI = *Bio::Emboss::ajStrPosI;
*Bio::Emboss::Str::ajStrPrefix = *Bio::Emboss::ajStrPrefix;
*Bio::Emboss::Str::ajStrPrefixC = *Bio::Emboss::ajStrPrefixC;
*Bio::Emboss::Str::ajStrPrefixCase = *Bio::Emboss::ajStrPrefixCase;
*Bio::Emboss::Str::ajStrPrefixCaseC = *Bio::Emboss::ajStrPrefixCaseC;
*Bio::Emboss::Str::ajStrQuote = *Bio::Emboss::ajStrQuote;
*Bio::Emboss::Str::ajStrQuoteStrip = *Bio::Emboss::ajStrQuoteStrip;
*Bio::Emboss::Str::ajStrRandom = *Bio::Emboss::ajStrRandom;
*Bio::Emboss::Str::ajStrReplace = *Bio::Emboss::ajStrReplace;
*Bio::Emboss::Str::ajStrReplaceC = *Bio::Emboss::ajStrReplaceC;
*Bio::Emboss::Str::ajStrReplaceK = *Bio::Emboss::ajStrReplaceK;
*Bio::Emboss::Str::ajStrRef = *Bio::Emboss::ajStrRef;
*Bio::Emboss::Str::ajStrRemoveHtml = *Bio::Emboss::ajStrRemoveHtml;
*Bio::Emboss::Str::ajStrRemoveNewline = *Bio::Emboss::ajStrRemoveNewline;
*Bio::Emboss::Str::ajStrRev = *Bio::Emboss::ajStrRev;
*Bio::Emboss::Str::ajStrRFindC = *Bio::Emboss::ajStrRFindC;
*Bio::Emboss::Str::ajStrRoom = *Bio::Emboss::ajStrRoom;
*Bio::Emboss::Str::ajStrSet = *Bio::Emboss::ajStrSet;
*Bio::Emboss::Str::ajStrSetC = *Bio::Emboss::ajStrSetC;
*Bio::Emboss::Str::ajStrSize = *Bio::Emboss::ajStrSize;
*Bio::Emboss::Str::ajStrSub = *Bio::Emboss::ajStrSub;
*Bio::Emboss::Str::ajStrSubstitute = *Bio::Emboss::ajStrSubstitute;
*Bio::Emboss::Str::ajStrSubstituteCC = *Bio::Emboss::ajStrSubstituteCC;
*Bio::Emboss::Str::ajStrSubstituteKK = *Bio::Emboss::ajStrSubstituteKK;
*Bio::Emboss::Str::ajStrSuffix = *Bio::Emboss::ajStrSuffix;
*Bio::Emboss::Str::ajStrSuffixC = *Bio::Emboss::ajStrSuffixC;
*Bio::Emboss::Str::ajStrToBool = *Bio::Emboss::ajStrToBool;
*Bio::Emboss::Str::ajStrToDouble = *Bio::Emboss::ajStrToDouble;
*Bio::Emboss::Str::ajStrToFloat = *Bio::Emboss::ajStrToFloat;
*Bio::Emboss::Str::ajStrToHex = *Bio::Emboss::ajStrToHex;
*Bio::Emboss::Str::ajStrToInt = *Bio::Emboss::ajStrToInt;
*Bio::Emboss::Str::ajStrTok = *Bio::Emboss::ajStrTok;
*Bio::Emboss::Str::ajStrTokC = *Bio::Emboss::ajStrTokC;
*Bio::Emboss::Str::ajStrToken = *Bio::Emboss::ajStrToken;
*Bio::Emboss::Str::ajStrTokenInit = *Bio::Emboss::ajStrTokenInit;
*Bio::Emboss::Str::ajStrTokenRest = *Bio::Emboss::ajStrTokenRest;
*Bio::Emboss::Str::ajStrToLong = *Bio::Emboss::ajStrToLong;
*Bio::Emboss::Str::ajStrToLower = *Bio::Emboss::ajStrToLower;
*Bio::Emboss::Str::ajStrToUpper = *Bio::Emboss::ajStrToUpper;
*Bio::Emboss::Str::ajStrTrace = *Bio::Emboss::ajStrTrace;
*Bio::Emboss::Str::ajStrTraceChars = *Bio::Emboss::ajStrTraceChars;
*Bio::Emboss::Str::ajStrTraceT = *Bio::Emboss::ajStrTraceT;
*Bio::Emboss::Str::ajStrTrim = *Bio::Emboss::ajStrTrim;
*Bio::Emboss::Str::ajStrTrimC = *Bio::Emboss::ajStrTrimC;
*Bio::Emboss::Str::ajStrTrimEndC = *Bio::Emboss::ajStrTrimEndC;
*Bio::Emboss::Str::ajStrTruncate = *Bio::Emboss::ajStrTruncate;
*Bio::Emboss::Str::ajStrWhole = *Bio::Emboss::ajStrWhole;
*Bio::Emboss::Str::ajStrWildPrefix = *Bio::Emboss::ajStrWildPrefix;
*Bio::Emboss::Str::ajStrWrap = *Bio::Emboss::ajStrWrap;
*Bio::Emboss::Str::ajStrWrapLeft = *Bio::Emboss::ajStrWrapLeft;
*Bio::Emboss::Str::ajTrnNew = *Bio::Emboss::ajTrnNew;
*Bio::Emboss::Str::ajUtilUid = *Bio::Emboss::ajUtilUid;
*Bio::Emboss::Str::ajXyzPdbtospBinSearch = *Bio::Emboss::ajXyzPdbtospBinSearch;
*Bio::Emboss::Str::ajXyzPdbToSp = *Bio::Emboss::ajXyzPdbToSp;
*Bio::Emboss::Str::ajXyzPdbToAcc = *Bio::Emboss::ajXyzPdbToAcc;
*Bio::Emboss::Str::ajXyzScopToPdb = *Bio::Emboss::ajXyzScopToPdb;
*Bio::Emboss::Str::ajXyzScopToSp = *Bio::Emboss::ajXyzScopToSp;
*Bio::Emboss::Str::ajXyzScopToAcc = *Bio::Emboss::ajXyzScopToAcc;
*Bio::Emboss::Str::ajXyzHitidxBinSearch = *Bio::Emboss::ajXyzHitidxBinSearch;
*Bio::Emboss::Str::embGrpMakeNewGnode = *Bio::Emboss::embGrpMakeNewGnode;
*Bio::Emboss::Str::embGrpMakeNewPnode = *Bio::Emboss::embGrpMakeNewPnode;
*Bio::Emboss::Str::ajGraphCheckColour = *Bio::Emboss::ajGraphCheckColour;

*Bio::Emboss::StrTok::ajStrTokenAss = *Bio::Emboss::ajStrTokenAss;
*Bio::Emboss::StrTok::ajStrTokenClear = *Bio::Emboss::ajStrTokenClear;
*Bio::Emboss::StrTok::ajStrTokenReset = *Bio::Emboss::ajStrTokenReset;
*Bio::Emboss::StrTok::ajStrTokenTrace = *Bio::Emboss::ajStrTokenTrace;

*Bio::Emboss::Trn::ajTrnDel = *Bio::Emboss::ajTrnDel;
*Bio::Emboss::Trn::ajTrnReadFile = *Bio::Emboss::ajTrnReadFile;
*Bio::Emboss::Trn::ajTrnCodon = *Bio::Emboss::ajTrnCodon;
*Bio::Emboss::Trn::ajTrnRevCodon = *Bio::Emboss::ajTrnRevCodon;
*Bio::Emboss::Trn::ajTrnCodonC = *Bio::Emboss::ajTrnCodonC;
*Bio::Emboss::Trn::ajTrnRevCodonC = *Bio::Emboss::ajTrnRevCodonC;
*Bio::Emboss::Trn::ajTrnCodonK = *Bio::Emboss::ajTrnCodonK;
*Bio::Emboss::Trn::ajTrnRevCodonK = *Bio::Emboss::ajTrnRevCodonK;
*Bio::Emboss::Trn::ajTrnC = *Bio::Emboss::ajTrnC;
*Bio::Emboss::Trn::ajTrnRevC = *Bio::Emboss::ajTrnRevC;
*Bio::Emboss::Trn::ajTrnAltRevC = *Bio::Emboss::ajTrnAltRevC;
*Bio::Emboss::Trn::ajTrnStr = *Bio::Emboss::ajTrnStr;
*Bio::Emboss::Trn::ajTrnRevStr = *Bio::Emboss::ajTrnRevStr;
*Bio::Emboss::Trn::ajTrnAltRevStr = *Bio::Emboss::ajTrnAltRevStr;
*Bio::Emboss::Trn::ajTrnSeq = *Bio::Emboss::ajTrnSeq;
*Bio::Emboss::Trn::ajTrnRevSeq = *Bio::Emboss::ajTrnRevSeq;
*Bio::Emboss::Trn::ajTrnAltRevSeq = *Bio::Emboss::ajTrnAltRevSeq;
*Bio::Emboss::Trn::ajTrnCFrame = *Bio::Emboss::ajTrnCFrame;
*Bio::Emboss::Trn::ajTrnStrFrame = *Bio::Emboss::ajTrnStrFrame;
*Bio::Emboss::Trn::ajTrnSeqFrame = *Bio::Emboss::ajTrnSeqFrame;
*Bio::Emboss::Trn::ajTrnSeqFramePep = *Bio::Emboss::ajTrnSeqFramePep;
*Bio::Emboss::Trn::ajTrnCDangle = *Bio::Emboss::ajTrnCDangle;
*Bio::Emboss::Trn::ajTrnStrDangle = *Bio::Emboss::ajTrnStrDangle;
*Bio::Emboss::Trn::ajTrnGetTitle = *Bio::Emboss::ajTrnGetTitle;
*Bio::Emboss::Trn::ajTrnGetFileName = *Bio::Emboss::ajTrnGetFileName;
*Bio::Emboss::Trn::ajTrnStartStop = *Bio::Emboss::ajTrnStartStop;
*Bio::Emboss::Trn::ajTrnStartStopC = *Bio::Emboss::ajTrnStartStopC;
*Bio::Emboss::Trn::ajTrnSeqOrig = *Bio::Emboss::ajTrnSeqOrig;

*Bio::Emboss::Vdwall::ajXyzVdwallDel = *Bio::Emboss::ajXyzVdwallDel;

*Bio::Emboss::Vdwres::ajXyzVdwresDel = *Bio::Emboss::ajXyzVdwresDel;

# --- list all methods of EMBOSS for the EXPORT :all tag

@ALL_METHODS = qw(
	embInitPerl
	ajGraphInitPerl
	ajAcdDebug
	ajAcdDebugIsSet
	ajAcdExit
	ajAcdFilter
	ajAcdGetAlign
	ajAcdGetArray
	ajAcdGetBool
	ajAcdGetCodon
	ajAcdGetDatafile
	ajAcdGetDirlist
	ajAcdGetFeat
	ajAcdGetFeatout
	ajAcdGetFilelist
	ajAcdGetFloat
	ajAcdGetGraph
	ajAcdGetGraphxy
	ajAcdGetInfile
	ajAcdGetInt
	ajAcdGetList
	ajAcdGetListI
	ajAcdGetMatrix
	ajAcdGetMatrixf
	ajAcdGetOutfile
	ajAcdGetCpdb
	ajAcdGetRange
	ajAcdGetRegexp
	ajAcdGetReport
	ajAcdGetScop
	ajAcdGetSelect
	ajAcdGetSelectI
	ajAcdGetSeq
	ajAcdGetSeqall
	ajAcdGetSeqout
	ajAcdGetSeqoutall
	ajAcdGetSeqoutset
	ajAcdGetSeqset
	ajAcdGetString
	ajAcdPrintType
	ajAcdProgram
	ajAcdProgramS
	ajAcdStdout
	ajAcdValue
	ajFeatIsChild
	ajFeatIsCompMult
	ajFeatCopy
	ajFeattableCopy
	ajFeatUfoRead
	ajFeatDel
	ajFeatExit
	ajFeatGetEnd
	ajFeatGetForward
	ajFeatGetFrame
	ajFeatGetLocs
	ajFeatGetNote
	ajFeatGetNoteI
	ajFeatGetStart
	ajFeatGetTag
	ajFeatGetType
	ajFeatGetTrans
	ajFeatIsLocal
	ajFeatIsLocalRange
	ajFeatIsMultiple
	ajFeatLocToSeq
	ajFeatNew
	ajFeatNewII
	ajFeatNewProt
	ajFeatRead
	ajFeatReverse
	ajFeatSetDesc
	ajFeatSetDescApp
	ajFeatSortByEnd
	ajFeatSortByStart
	ajFeatSortByType
	ajFeattableAdd
	ajFeattableBegin
	ajFeattableClear
	ajFeattableDel
	ajFeattableEnd
	ajFeattableGetName
	ajFeattableIsNuc
	ajFeattableIsProt
	ajFeattableLen
	ajFeattableNew
	ajFeattableNewDna
	ajFeattableNewProt
	ajFeattableNewSeq
	ajFeattablePos
	ajFeattablePosI
	ajFeattablePosII
	ajFeattableReverse
	ajFeattableSetDna
	ajFeattableSetProt
	ajFeattableSetRange
	ajFeattableSize
	ajFeattableTrace
	ajFeattableWriteDdbj
	ajFeattableWriteEmbl
	ajFeattableWriteGenbank
	ajFeattableWriteGff
	ajFeattableWritePir
	ajFeattableWriteSwiss
	ajFeattabInClear
	ajFeattabInDel
	ajFeattabInNew
	ajFeattabInNewSS
	ajFeattabInNewSSF
	ajFeattabOutDel
	ajFeattabOutFile
	ajFeattabOutFilename
	ajFeattabOutIsOpen
	ajFeattabOutNew
	ajFeattabOutNewSSF
	ajFeattabOutOpen
	ajFeattabOutSet
	ajFeatTagAdd
	ajFeatTagAddC
	ajFeatTagAddCC
	ajFeatTagIter
	ajFeatTagSet
	ajFeatTagSetC
	ajFeatTagTrace
	ajFeatTagval
	ajFeatTest
	ajFeatTrace
	ajFeatUfoWrite
	ajFeatWrite
	ajFileBuffClear
	ajFileBuffDel
	ajFileBuffEmpty
	ajFileBuffEnd
	ajFileBuffEof
	ajFileBuffFile
	ajFileBuffFix
	ajFileBuffFp
	ajFileBuffFreeClear
	ajFileBuffGet
	ajFileBuffGetL
	ajFileBuffGetStore
	ajFileBuffLoad
	ajFileBuffLoadC
	ajFileBuffLoadS
	ajFileBuffNew
	ajFileBuffNewDC
	ajFileBuffNewDF
	ajFileBuffNewDW
	ajFileBuffNewFile
	ajFileBuffNewIn
	ajFileBuffNewInList
	ajFileBuffNewS
	ajFileBuffNobuff
	ajFileBuffReset
	ajFileBuffResetPos
	ajFileBuffSetFile
	ajFileBuffSize
	ajFileBuffStripHtml
	ajFileBuffStripSrs
	ajFileBuffTrace
	ajFileBuffTraceFull
	ajFileClose
	ajFileDataDirNew
	ajFileDataDirNewC
	ajFileDataNew
	ajFileDataNewC
	ajFileDataNewWrite
	ajFileDir
	ajFileDirFix
	ajFileDirUp
	ajFileDirPath
	ajFileDirTrim
	ajFileExit
	ajFileFileList
	ajFileFp
	ajFileGetwd
	ajFileGetName
	ajFileGets
	ajFileGetsL
	ajFileGetsTrim
	ajFileGetsTrimL
	ajFileLength
	ajFileName
	ajFileNameDirSet
	ajFileNameDirSetC
	ajFileNameExt
	ajFileNameExtC
	ajFileNameShorten
	ajFileNameTrim
	ajFileNew
	ajFileNewApp
	ajFileNewDC
	ajFileNewDF
	ajFileNewDW
	ajFileNewF
	ajFileNewIn
	ajFileNewInC
	ajFileNewInPipe
	ajFileNewInList
	ajFileNewOut
	ajFileNewOutD
	ajFileOutHeader
	ajFileOutClose
	ajFileNext
	ajFileRead
	ajFileReopen
	ajFileReadLine
	ajFileReadUint
	ajFileScan
	ajFileSeek
	ajFileStat
	ajFileStderr
	ajFileStdin
	ajFileStdout
	ajFileTell
	ajFileTempName
	ajFileTestSkip
	ajFileTrace
	ajFileUnbuffer
	ajFileWrite
	ajFileWriteByte
	ajFileWriteChar
	ajFileWriteInt2
	ajFileWriteInt4
	ajFileWriteInt8
	ajFileWriteStr
	ajHistClose
	ajHistCopyData
	ajHistDelete
	ajHistDisplay
	ajHistNew
	ajHistNewG
	ajHistSetBlackandWhite
	ajHistSetColour
	ajHistSetMultiTitle
	ajHistSetMultiTitleC
	ajHistSetMultiXTitle
	ajHistSetMultiXTitleC
	ajHistSetMultiYTitle
	ajHistSetMultiYTitleC
	ajHistSetPattern
	ajHistSetPtrToData
	ajHistSetTitleC
	ajHistSetXAxisC
	ajHistSetYAxisLeftC
	ajHistSetYAxisRightC
	ajListAppend
	ajListIterFree
	ajListCopy
	ajListDel
	ajListFree
	ajListInsert
	ajListIter
	ajListIterBack
	ajListIterBackDone
	ajListIterBackMore
	ajListIterBackNext
	ajListIterNext
	ajListIterMore
	ajListIterDone
	ajListIterTrace
	ajListLength
	ajListNew
	ajListPush
	ajListPushApp
	ajListReverse
	ajListstrCopy
	ajListstrDel
	ajListstrFree
	ajListstrIterTrace
	ajListstrLength
	ajListstrNew
	ajListstrPop
	ajListstrPopEnd
	ajListstrPush
	ajListstrPushApp
	ajListstrReverse
	ajListstrToArray
	ajListstrTrace
	ajListTrace
	ajListPushList
	ajListstrPushList
	ajListRemove
	ajListstrClone
	ajListstrInsert
	ajListstrRemove
	ajListSort
	ajDegToRad
	ajGaussProb
	ajGeoMean
	ajPolToRec
	ajPosMod
	ajRadToDeg
	ajRandomNumber
	ajRandomNumberD
	ajRandomSeed
	ajRecToPol
	ajRound
	ajRoundF
	ajMemAlloc
	ajMemCalloc
	ajMemCalloc0
	ajMemResize
	ajMemFree
	ajMemStat
	ajMemExit
	ajNamDatabase
	ajNamDbDetails
	ajNamDbGetDbalias
	ajNamDbGetUrl
	ajNamDbData
	ajNamDbQuery
	ajNamDbTest
	ajNamDebugOrigin
	ajNamDebugDatabases
	ajNamExit
	ajNamGetenv
	ajNamGetValue
	ajNamGetValueC
	ajNamInit
	ajNamListDatabases
	ajNamListListDatabases
	ajNamListOrigin
	ajNamPrintDbAttr
	ajNamResolve
	ajNamRoot
	ajNamRootBase
	ajNamRootInstall
	ajNamRootPack
	ajNamRootVersion
	ajRangeNewI
	ajRangeDefault
	ajRangeDel
	ajRangeGet
	ajRangeFile
	ajRangeStrExtract
	ajRangeStrExtractList
	ajRangeStrStuff
	ajRangeStrMask
	ajRangeNumber
	ajRangeText
	ajRangeValues
	ajRangeChange
	ajRangeBegin
	ajRangeOverlapSingle
	ajRangeOverlaps
	ajRangeOrdered
	ajReportClose
	ajReportDel
	ajReportOpen
	ajReportFileAdd
	ajReportFindFormat
	ajReportFormatDefault
	ajReportNew
	ajReportPrintFormat
	ajReportSeqName
	ajReportSetHeader
	ajReportSetHeaderC
	ajReportSetTags
	ajReportSetTail
	ajReportSetTailC
	ajReportSetType
	ajReportWriteTail
	ajReportValid
	ajReportWrite
	ajReportWriteHeader
	ajIsAccession
	ajIsSeqversion
	ajSelexNew
	ajSelexDel
	ajSelexdataNew
	ajSelexdataDel
	ajSelexSQDel
	ajSelexSQNew
	ajStockholmNew
	ajStockholmDel
	ajStockholmdataDel
	ajStockholmdataNew
	ajSeqallBegin
	ajSeqallDel
	ajSeqallEnd
	ajSeqallGetName
	ajSeqallGetNameSeq
	ajSeqallGetRange
	ajSeqallGetUsa
	ajSeqallLen
	ajSeqallNew
	ajSeqallNext
	ajSeqallReverse
	ajSeqallSetRange
	ajSeqallToLower
	ajSeqallToUpper
	ajSeqAssAcc
	ajSeqAssAccC
	ajSeqAssDesc
	ajSeqAssDescC
	ajSeqAssEntry
	ajSeqAssEntryC
	ajSeqAssFile
	ajSeqAssFull
	ajSeqAssFullC
	ajSeqAssGi
	ajSeqAssGiC
	ajSeqAssName
	ajSeqAssNameC
	ajSeqAssSeq
	ajSeqAssSeqC
	ajSeqAssSeqCI
	ajSeqAssSv
	ajSeqAssSvC
	ajSeqAssUfo
	ajSeqAssUfoC
	ajSeqAssUsa
	ajSeqAssUsaC
	ajSeqBaseComp
	ajSeqBegin
	ajSeqChar
	ajSeqCharCopy
	ajSeqCharCopyL
	ajSeqCheckGcg
	ajSeqClear
	ajSeqCompOnly
	ajSeqCompOnlyStr
	ajSeqCopyFeat
	ajSeqCount
	ajSeqCrc
	ajSeqCvtDel
	ajSeqCvtK
	ajSeqCvtLen
	ajSeqCvtNew
	ajSeqCvtNewText
	ajSeqCvtNewZero
	ajSeqCvtTrace
	ajSeqDel
	ajSeqEnd
	ajSeqFill
	ajSeqGapCount
	ajSeqGapCountS
	ajSeqGapStandard
	ajSeqGetAcc
	ajSeqGetDesc
	ajSeqGetEntry
	ajSeqGetFeat
	ajSeqGetGi
	ajSeqGetName
	ajSeqGetRange
	ajSeqGetReverse
	ajSeqGetSv
	ajSeqGetUsa
	ajSeqinTrace
	ajSeqIsNuc
	ajSeqIsProt
	ajSeqLen
	ajSeqMakeUsa
	ajSeqMod
	ajSeqMW
	ajSeqName
	ajSeqNew
	ajSeqNewL
	ajSeqNewS
	ajSeqNum
	ajSeqOffset
	ajSeqOffend
	ajSeqPos
	ajSeqPosI
	ajSeqPosII
	ajSeqQueryClear
	ajSeqQueryDel
	ajSeqQueryIs
	ajSeqQueryNew
	ajSeqQueryStarclear
	ajSeqQueryTrace
	ajSeqQueryWild
	ajSeqReplace
	ajSeqReplaceC
	ajSeqReverse
	ajSeqReverseStr
	ajSeqRevOnly
	ajSeqsetBegin
	ajSeqsetDel
	ajSeqsetEnd
	ajSeqsetFill
	ajSeqsetGetFormat
	ajSeqsetGetName
	ajSeqsetGetRange
	ajSeqsetGetSeq
	ajSeqsetGetUsa
	ajSeqsetIsDna
	ajSeqsetIsNuc
	ajSeqsetIsProt
	ajSeqsetIsRna
	ajSeqsetLen
	ajSeqsetName
	ajSeqsetNew
	ajSeqSetRange
	ajSeqsetReverse
	ajSeqsetSeq
	ajSeqsetSetRange
	ajSeqsetSize
	ajSeqsetToLower
	ajSeqsetTotweight
	ajSeqsetToUpper
	ajSeqsetWeight
	ajSeqStr
	ajSeqStrCopy
	ajSeqToLower
	ajSeqToUpper
	ajSeqTrace
	ajSeqFindOutFormat
	ajSeqTrim
	ajSeqABIGetBaseOffset
	ajSeqABIGetBasePosition
	ajSeqABIGetBasePosOffset
	ajSeqABIGetBaseSpace
	ajSeqABIGetData
	ajSeqABIGetFWO
	ajSeqABIGetNBase
	ajSeqABIGetNData
	ajSeqABIGetPrimerOffset
	ajSeqABIGetPrimerPosition
	ajSeqABIGetSignal
	ajSeqABIGetTraceOffset
	ajSeqABIMachineName
	ajSeqABIReadSeq
	ajSeqABISampleName
	ajSeqABITest
	ajSeqAccessAsis
	ajSeqAccessFile
	ajSeqAccessOffset
	ajSeqMethod
	ajSeqPrintAccess
	ajSeqallFile
	ajSeqAllRead
	ajSeqGetFromUsa
	ajSeqinClear
	ajSeqinDel
	ajSeqinNew
	ajSeqParseFasta
	ajSeqParseNcbi
	ajSeqinSetNuc
	ajSeqinSetProt
	ajSeqinSetRange
	ajSeqinUsa
	ajSeqPrintInFormat
	ajSeqRead
	ajSeqsetApp
	ajSeqsetRead
	ajSeqsetFromList
	ajSeqsetFromPair
	ajSeqGap
	ajSeqGapLen
	ajSeqGapS
	ajSeqPrintType
	ajSeqSetNuc
	ajSeqSetProt
	ajSeqType
	ajSeqAllWrite
	ajSeqFileNewOut
	ajSeqoutCheckGcg
	ajSeqoutClear
	ajSeqoutDel
	ajSeqOutFormatDefault
	ajSeqOutFormatSingle
	ajSeqoutNew
	ajSeqoutNewF
	ajSeqoutOpen
	ajSeqOutSetFormat
	ajSeqOutSetFormatC
	ajSeqoutTrace
	ajSeqPrintOutFormat
	ajSeqoutUsa
	ajSeqsetWrite
	ajSeqWrite
	ajSeqWriteClose
	ajSeqWriteXyz
	ajSssWriteXyz
	ajCharFree
	ajCharNewC
	ajStrFix
	ajStrFixI
	ajStrFixTestI
	ajStrStr
	ajStrTokenCount
	ajStrTokenCountR
	ajCharNew
	ajCharNewL
	ajCharNewLS
	ajCharPos
	ajCharToLower
	ajCharToUpper
	ajStrApp
	ajStrAppC
	ajStrAppK
	ajStrAppKI
	ajStrAppSub
	ajStrAss
	ajStrAssC
	ajStrAssCI
	ajStrAssCL
	ajStrAssI
	ajStrAssL
	ajStrAssS
	ajStrAssSub
	ajStrAssSubC
	ajStrBlock
	ajStrBool
	ajStrChar
	ajStrCheck
	ajStrChomp
	ajStrChompC
	ajStrChompEnd
	ajStrChop
	ajStrClean
	ajStrCleanWhite
	ajStrClear
	ajStrCmpC
	ajStrCmpCase
	ajStrCmpCaseCC
	ajStrCmp
	ajStrCmpO
	ajStrCmpWild
	ajStrCmpWildC
	ajStrCmpWildCC
	ajStrConvert
	ajStrConvertCC
	ajStrCopy
	ajStrCopyC
	ajStrCountC
	ajStrCountK
	ajStrCut
	ajStrDegap
	ajStrDel
	ajStrDelim
	ajStrDelReuse
	ajStrDup
	ajStrExit
	ajStrFind
	ajStrFindC
	ajStrFindCase
	ajStrFindCaseC
	ajStrFill
	ajStrFromBool
	ajStrFromDouble
	ajStrFromDoubleE
	ajStrFromFloat
	ajStrFromInt
	ajStrFromLong
	ajStrInsert
	ajStrInsertC
	ajStrIsAlnum
	ajStrIsAlpha
	ajStrIsBool
	ajStrIsDouble
	ajStrIsFloat
	ajStrIsHex
	ajStrIsInt
	ajStrIsLong
	ajStrIsSpace
	ajStrIsWild
	ajStrIsWord
	ajStrIter
	ajStrIterBack
	ajStrIterBackNext
	ajStrIterFree
	ajStrIterNext
	ajStrJoin
	ajStrJoinC
	ajStrLen
	ajStrMask
	ajStrMatch
	ajStrMatchC
	ajStrMatchCase
	ajStrMatchCaseC
	ajStrMatchCaseCC
	ajStrMatchCC
	ajStrMatchWild
	ajStrMatchWildC
	ajStrMatchWildCC
	ajStrMatchWildCO
	ajStrMatchWord
	ajStrMatchWordC
	ajStrMatchWordCC
	ajStrMod
	ajStrModL
	ajStrNCmpC
	ajStrNCmpCaseCC
	ajStrNCmpO
	ajStrNew
	ajStrNewC
	ajStrNewCIL
	ajStrNewCL
	ajStrNewL
	ajStrNewS
	ajStrPos
	ajStrPosI
	ajStrPosII
	ajStrPrefix
	ajStrPrefixC
	ajStrPrefixCC
	ajStrPrefixCase
	ajStrPrefixCaseC
	ajStrPrefixCaseCC
	ajStrPrefixCaseCO
	ajStrPrefixCO
	ajStrQuote
	ajStrQuoteStrip
	ajStrRandom
	ajStrReplace
	ajStrReplaceC
	ajStrReplaceK
	ajStrRef
	ajStrRemoveHtml
	ajStrRemoveNewline
	ajStrRev
	ajStrRFindC
	ajStrRoom
	ajStrSet
	ajStrSetC
	ajStrSize
	ajStrStat
	ajStrSub
	ajStrSubstitute
	ajStrSubstituteCC
	ajStrSubstituteKK
	ajStrSuffix
	ajStrSuffixC
	ajStrSuffixCC
	ajStrSuffixCO
	ajStrToBool
	ajStrToDouble
	ajStrToFloat
	ajStrToHex
	ajStrToInt
	ajStrTok
	ajStrTokC
	ajStrToken
	ajStrTokenAss
	ajStrTokenClear
	ajStrTokenInit
	ajStrTokenReset
	ajStrTokenRest
	ajStrTokenTrace
	ajStrToLong
	ajStrToLower
	ajStrToUpper
	ajStrTrace
	ajStrTraceChars
	ajStrTraceT
	ajStrTrim
	ajStrTrimC
	ajStrTrimEndC
	ajStrTruncate
	ajStrWhole
	ajStrWildPrefix
	ajStrWrap
	ajStrWrapLeft
	ajStrYN
	ajTrnDel
	ajTrnNew
	ajTrnNewI
	ajTrnNewC
	ajTrnReadFile
	ajTrnNewPep
	ajTrnCodon
	ajTrnRevCodon
	ajTrnCodonC
	ajTrnRevCodonC
	ajTrnCodonK
	ajTrnRevCodonK
	ajTrnC
	ajTrnRevC
	ajTrnAltRevC
	ajTrnStr
	ajTrnRevStr
	ajTrnAltRevStr
	ajTrnSeq
	ajTrnRevSeq
	ajTrnAltRevSeq
	ajTrnCFrame
	ajTrnStrFrame
	ajTrnSeqFrame
	ajTrnSeqFramePep
	ajTrnCDangle
	ajTrnStrDangle
	ajTrnGetTitle
	ajTrnGetFileName
	ajTrnStartStop
	ajTrnStartStopC
	ajTrnSeqOrig
	ajExit
	ajExitBad
	ajLogInfo
	ajUtilBigendian
	ajUtilCatch
	ajUtilRev2
	ajUtilRev4
	ajUtilRev8
	ajUtilUid
	ajXyzPdbtospNew
	ajXyzPdbtospDel
	ajXyzPdbtospRead
	ajXyzPdbtospReadC
	ajXyzPdbtospReadAll
	ajXyzPdbtospBinSearch
	ajXyzSortPdbtospPdb
	ajXyzAtomNew
	ajXyzAtomDel
	ajXyzInContact
	ajXyzAtomDistance
	ajXyzChainNew
	ajXyzChainDel
	ajXyzPdbNew
	ajXyzPdbDel
	ajXyzPdbWriteAll
	ajXyzPdbWriteDomain
	ajXyzPdbChain
	ajXyzPdbAtomIndexI
	ajXyzPdbAtomIndexC
	ajXyzPdbAtomIndexICA
	ajXyzPdbAtomIndexCCA
	ajXyzPdbToSp
	ajXyzPdbToAcc
	ajXyzCpdbRead
	ajXyzCpdbReadFirstModel
	ajXyzCpdbReadOld
	ajXyzCpdbWriteAll
	ajXyzCpdbWriteDomain
	ajXyzScopNew
	ajXyzScopDel
	ajXyzScopRead
	ajXyzScopReadC
	ajXyzScopReadAll
	ajXyzScopWrite
	ajXyzScopToPdb
	ajXyzScopToSp
	ajXyzScopToAcc
	ajXyzScopToScophit
	ajXyzScopCompId
	ajXyzScopCopy
	ajXyzScopclaNew
	ajXyzScopclaDel
	ajXyzScopclaRead
	ajXyzScopclaReadC
	ajXyzScopdesNew
	ajXyzScopdesDel
	ajXyzScopdesRead
	ajXyzScopdesReadC
	ajXyzScophitNew
	ajXyzScophitDel
	ajXyzScophitsToHitlist
	ajXyzScophitsOverlap
	ajXyzScophitsOverlapAcc
	ajXyzScophitCopy
	ajXyzScophitListCopy
	ajXyzScophitToHit
	ajXyzScophitCheckTarget
	ajXyzScophitTarget
	ajXyzScophitTarget2
	ajXyzScophitTargetLowPriority
	ajXyzScophitMergeInsertThis
	ajXyzScophitMergeInsertOther
	ajXyzScophitMerge
	ajXyzScophitCompSpr
	ajXyzScophitCompStart
	ajXyzScophitCompFold
	ajXyzScophitCompSfam
	ajXyzScophitCompFam
	ajXyzScophitCompAcc
	ajXyzHitNew
	ajXyzHitDel
	ajXyzHitsOverlap
	ajXyzCompScore
	ajXyzCompScoreInv
	ajXyzCompId
	ajXyzHitlistNew
	ajXyzHitlistDel
	ajXyzHitlistRead
	ajXyzHitlistReadNode
	ajXyzHitlistReadFam
	ajXyzHitlistReadSfam
	ajXyzHitlistReadFold
	ajXyzHitlistWrite
	ajXyzHitlistToScophits
	ajXyzHitlistClassify
	ajXyzHitlistPriorityHigh
	ajXyzHitlistPriorityLow
	ajXyzHitlistToThreeScophits
	ajXyzHitlistsWriteFasta
	ajXyzPrintPdbSeqresChain
	ajXyzPrintPdbSeqresDomain
	ajXyzPrintPdbAtomChain
	ajXyzPrintPdbAtomDomain
	ajXyzPrintPdbHeterogen
	ajXyzPrintPdbText
	ajXyzPrintPdbHeader
	ajXyzPrintPdbHeaderScop
	ajXyzPrintPdbTitle
	ajXyzPrintPdbCompnd
	ajXyzPrintPdbSource
	ajXyzPrintPdbEmptyRemark
	ajXyzPrintPdbResolution
	ajXyzScopalgRead
	ajXyzScopalgWrite
	ajXyzScopalgWriteClustal
	ajXyzScopalgWriteClustal2
	ajXyzScopalgNew
	ajXyzScopalgDel
	ajXyzScopalgGetseqs
	ajXyzCmapNew
	ajXyzCmapDel
	ajXyzCmapRead
	ajXyzCmapReadC
	ajXyzCmapReadI
	ajXyzVdwRad
	ajXyzVdwallNew
	ajXyzVdwallDel
	ajXyzVdwallRead
	ajXyzVdwresNew
	ajXyzVdwresDel
	ajXyzScorealgNew
	ajXyzScorealgDel
	ajXyzSigdatNew
	ajXyzSigposNew
	ajXyzSigdatDel
	ajXyzSigposDel
	ajXyzHitidxNew
	ajXyzHitidxDel
	ajXyzHitidxBinSearch
	ajXyzSignatureNew
	ajXyzSignatureDel
	ajXyzSignatureRead
	ajXyzSignatureWrite
	ajXyzSignatureCompile
	ajXyzSignatureAlignSeq
	ajXyzSignatureAlignSeqall
	ajXyzSignatureHitsWrite
	ajXyzSignatureAlignWrite
	ajXyzHetentNew
	ajXyzHetentDel
	ajXyzHetNew
	ajXyzHetDel
	ajXyzHetRawRead
	ajXyzHetRead
	ajXyzHetWrite
	embGrpCompareTwoGnodes
	embGrpGetProgGroups
	embGrpGroupsListDel
	embGrpKeySearchProgs
	embGrpKeySearchSeeAlso
	embGrpMakeNewGnode
	embGrpMakeNewPnode
	embGrpOutputGroupsList
	embGrpOutputProgsList
	embGrpSortGroupsList
	embGrpMakeUnique
	ajGraphBox
	ajGraphBoxFill
	ajGraphCheckColour
	ajGraphCircle
	ajGraphClose
	ajGraphCloseWin
	ajGraphColourBack
	ajGraphColourFore
	ajGraphDataDel
	ajGraphDataObjAddLine
	ajGraphDataObjAddRect
	ajGraphDataObjAddText
	ajGraphDataxySetMaxMin
	ajGraphDataxyMaxMin
	ajGraphDataxySetMaxima
	ajGraphDataxySetTypeC
	ajGraphDia
	ajGraphDiaFill
	ajGraphDots
	ajGraphDumpDevices
	ajGraphGetCharSize
	ajGraphGetColour
	ajGraphGetOut
	ajGraphHoriBars
	ajGraphInfo
	ajGraphInitSeq
	ajGraphLabel
	ajGraphLabelYRight
	ajGraphLine
	ajGraphLines
	ajGraphNew
	ajGraphNewPage
	ajGraphObjAddLine
	ajGraphObjAddRect
	ajGraphObjAddText
	ajGraphObjDel
	ajGraphDataObjDel
	ajGraphOpen
	ajGraphOpenPlot
	ajGraphOpenWin
	ajGraphPlenv
	ajGraphPoly
	ajGraphPolyFill
	ajGraphPrintType
	ajGraphRect
	ajGraphRectFill
	ajGraphSet
	ajGraphSetDevice
	ajGraphSetCharSize
	ajGraphSetBackBlack
	ajGraphSetBackWhite
	ajGraphSetPenWidth
	ajGraphSetFillPat
	ajGraphSetFore
	ajGraphSetLineStyle
	ajGraphSetMulti
	ajGraphSetName
	ajGraphSetOri
	ajGraphSymbols
	ajGraphText
	ajGraphTextEnd
	ajGraphTextMid
	ajGraphTextLine
	ajGraphTextStart
	ajGraphTrace
	ajGraphTraceInt
	ajGraphTri
	ajGraphTriFill
	ajGraphUnused
	ajGraphVertBars
	ajGraphxyAddDataCalcPtr
	ajGraphxyAddDataPtrPtr
	ajGraphxyAddGraph
	ajGraphxyReplaceGraph
	ajGraphxyDataNew
	ajGraphxyDataNewI
	ajGraphxyDataSetSubtitle
	ajGraphxyDataSetSubtitleC
	ajGraphxyDataSetTitle
	ajGraphxyDataSetTitleC
	ajGraphxyDataSetXtitle
	ajGraphxyDataSetXtitleC
	ajGraphxyDataSetYtitle
	ajGraphxyDataSetYtitleC
	ajGraphxyDel
	ajGraphxyDisplay
	ajGraphxyInitGraphCalcPtr
	ajGraphxyNewI
	ajGraphxyCheckMaxMin
	ajGraphxySet
	ajGraphxySetCirclePoints
	ajGraphxySetColour
	ajGraphxySetFlag
	ajGraphxySetGaps
	ajGraphxySetJoinPoints
	ajGraphxySetLineType
	ajGraphxySetMaxMin
	ajGraphxySetOut
	ajGraphxySetOutC
	ajGraphxySetOverLap
	ajGraphxySetSubtitleDo
	ajGraphxySetTitleDo
	ajGraphxySetXBottom
	ajGraphxySetXLabelTop
	ajGraphxySetXTick
	ajGraphxySetXTop
	ajGraphxySetXEnd
	ajGraphxySetXGrid
	ajGraphxySetXInvTicks
	ajGraphxySetXLabel
	ajGraphxySetXRangeII
	ajGraphxySetXStart
	ajGraphxySetYLabelLeft
	ajGraphxySetYLeft
	ajGraphxySetYRight
	ajGraphxySetYTick
	ajGraphxySetYEnd
	ajGraphxySetYGrid
	ajGraphxySetYInvTicks
	ajGraphxySetYLabel
	ajGraphxySetYRangeII
	ajGraphxySetYStart
	ajGraphxySubtitle
	ajGraphxySubtitleC
	ajGraphxyTitle
	ajGraphxyTitleC
	ajGraphxyXtitle
	ajGraphxyXtitleC
	ajGraphxyYtitle
	ajGraphxyYtitleC
	ajGraphPartCircle
	ajGraphDrawTextOnCurve
	ajGraphRectangleOnCurve
	ajGraphTextLength
	ajGraphTextHeight
	ajGraphDistPts
	ajGraphFitTextOnLine
	ajGraphSetDefCharSize
	ajGraphFillRectangleOnCurve
	ajGraphPlpDataAddLine
	ajGraphPlpDataAddRect
	ajGraphPlpDataAddText
	ajGraphPlpDataSetMaxMin
	ajGraphArrayMaxMin
	ajGraphPlpDataSetMaxima
	ajGraphPlpDataSetTypeC
	ajGraphPlpDataTrace
	ajGraphClear
	ajGraphGetSubTitle
	ajGraphGetSubTitleC
	ajGraphGetTitle
	ajGraphGetTitleC
	ajGraphGetXTitle
	ajGraphGetXTitleC
	ajGraphGetYTitle
	ajGraphGetYTitleC
	ajGraphIsData
	ajGraphAddLine
	ajGraphAddRect
	ajGraphAddText
	ajGraphPlpDataDel
	ajGraphPlpDataCalcXY
	ajGraphPlpDataSetXY
	ajGraphDataAdd
	ajGraphDataReplace
	ajGraphPlpDataNew
	ajGraphPlpDataNewI
	ajGraphPlpDataSetSubTitle
	ajGraphPlpDataSetSubTitleC
	ajGraphPlpDataSetTitle
	ajGraphPlpDataSetTitleC
	ajGraphPlpDataSetXTitle
	ajGraphPlpDataSetXTitleC
	ajGraphPlpDataSetYTitle
	ajGraphPlpDataSetYTitleC
	ajGraphPlpDataSetColour
	ajGraphSetFlag
	ajGraphPlpDataSetLineType
	ajGraphSetOut
	ajGraphSetOutC
	ajGraphSetSubTitleDo
	ajGraphSetTitleDo
	ajGraphSetSubTitle
	ajGraphSetSubTitleC
	ajGraphSetTitle
	ajGraphSetTitleC
	ajGraphSetXTitle
	ajGraphSetXTitleC
	ajGraphSetYTitle
	ajGraphSetYTitleC
	ajComputeCoord
	);

# --- list ajAcdGet... methods of EMBOSS for the EXPORT :acd tag

@ACD_METHODS = qw(
	ajAcdGetAlign
	ajAcdGetArray
	ajAcdGetBool
	ajAcdGetCodon
	ajAcdGetDatafile
	ajAcdGetDirlist
	ajAcdGetFeat
	ajAcdGetFeatout
	ajAcdGetFilelist
	ajAcdGetFloat
	ajAcdGetGraph
	ajAcdGetGraphxy
	ajAcdGetInfile
	ajAcdGetInt
	ajAcdGetList
	ajAcdGetListI
	ajAcdGetMatrix
	ajAcdGetMatrixf
	ajAcdGetOutfile
	ajAcdGetCpdb
	ajAcdGetRange
	ajAcdGetRegexp
	ajAcdGetReport
	ajAcdGetScop
	ajAcdGetSelect
	ajAcdGetSelectI
	ajAcdGetSeq
	ajAcdGetSeqall
	ajAcdGetSeqout
	ajAcdGetSeqoutall
	ajAcdGetSeqoutset
	ajAcdGetSeqset
	ajAcdGetString
	);

1;
